#
# @summary : determine the benchmark to be used for the manifest
#
# This function determins the  product_version to use for this call. It uses the following algorithmn:
# 
# 1. Use the specified version for this database
# 2. Use a generic specified version for all databases
# 3. Check if fact ora_version is set. If not, return an undef
# 4. Use the version based on the version of the database
#
# @param [String[1]] sid The database sid
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function('ora_secured::default_product_version') do
  dispatch :default_product_version do
    param 'String[1]', :sid
  end

  def default_product_version(sid)
    #
    # When a version is specified, use it.
    #
    value = lookup_setting('product_version', nil)
    return value if value
    #
    # When the version fact is available, use it
    #
    return nil unless closure_scope.include?('ora_version')
    product_version = product_version(closure_scope['ora_version'], sid).first
    case product_version
    when /^12\..*/
      'db12c'
    when /^18\..*/
      'db18c'
    when /^19\..*/
      'db19c'
    else
      fail "Database version #{product_version} not recognised"
    end
  end

  def lookup_setting(sid, default_value)
    call_function('ora_secured::lookup_setting', sid, default_value )
  end

  def product_version(data, sid)
    call_function('ora_config::on_sid', data, sid)
  end

end
  