#
# @summary Filter the list of controls based on the which database it will be applied to
#
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function('ora_secured::filter_controls') do
  dispatch :filter_controls do
    param 'String[1]',                  :title
    param 'Hash[String[1], String[1]]', :controls
  end

  def filter_controls(title, controls)
    # Return all controls unless we are running on a pluggable database
    return controls unless call_function('ora_config::is_pluggable_db', title)
    # Issue a warning that we will skip this control
    nonpdb_controls.each do | control|
      call_function( 'alert', "#{control} in skipped on #{title} because not applicable on pluggable database") if controls.include?(control)
    end
    # Return all controls with the pdb controls
    controls.reject{|_,v| nonpdb_controls.include?(v)}
  end

  def nonpdb_controls
    @nonpdb_controls ||= call_function( 'lookup','ora_secured::nonpdb_controls', data_type('Array[String[1]]'), nil, nil)
  end

  def data_type(string)
    parser = Puppet::Pops::Types::TypeParser.singleton
    parser.parse(string)
  end

end
    