#
# ora_secured::controls::access_to_default_accounts_used_to_support_replication_must_be_restricted_to_authorized_dbas
#
# @summary From SQL*Plus:
# select 'The number of replication objects defined is: '||
#   count(*) from all_tables 
#   where table_name like 'REPCAT%';
# 
# If the count returned is 0, then Oracle Replication is not installed and this check is not a finding.
# 
# Otherwise:
# 
# 
#   select count(*) from sys.dba_repcatlog;
# 
# If the count returned is 0, then Oracle Replication is not in use and this check is not a finding.
# 
# If any results are returned, ask the ISSO or DBA if the replication account (the default is REPADMIN, but may be customized) is restricted to ISSO-authorized personnel only.
# 
# If it is not, this is a finding.
# 
# If there are multiple replication accounts, confirm that all are justified and documented with the ISSO.
# 
# If they are not, this is a finding.
# 
# Note: Oracle Database Advanced Replication is deprecated in Oracle Database 12c. Use Oracle GoldenGate to replace all features of Advanced Replication, including multimaster replication, updatable materialized views, hierarchical materialized views, and deployment templates.
# 
# Change the password for default and custom replication accounts and provide the password to ISSO-authorized users only.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::access_to_default_accounts_used_to_support_replication_must_be_restricted_to_authorized_dbas: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::access_to_default_accounts_used_to_support_replication_must_be_restricted_to_authorized_dbas::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `access_to_default_accounts_used_to_support_replication_must_be_restricted_to_authorized_dbas` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61411
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::access_to_default_accounts_used_to_support_replication_must_be_restricted_to_authorized_dbas
{
  ora_secured_setup { "access_to_default_accounts_used_to_support_replication_must_be_restricted_to_authorized_dbas on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
