#
# ora_secured::controls::administrative_privileges_must_be_assigned_to_database_accounts_via_database_roles
#
# @summary Review accounts for direct assignment of administrative privileges.
# Connected as SYSDBA, run the query:
# 
# SELECT grantee, privilege
# FROM   dba_sys_privs
# WHERE  grantee IN 
# (
# SELECT username
# FROM   dba_users
# WHERE  username NOT IN 
# (
# 'XDB', 'SYSTEM', 'SYS', 'LBACSYS',
# 'DVSYS', 'DVF', 'SYSMAN_RO',
# 'SYSMAN_BIPLATFORM', 'SYSMAN_MDS',
# 'SYSMAN_OPSS', 'SYSMAN_STB', 'DBSNMP',
# 'SYSMAN', 'APEX_040200', 'WMSYS',
# 'SYSDG', 'SYSBACKUP', 'SPATIAL_WFS_ADMIN_USR',
# 'SPATIAL_CSW_ADMIN_US', 'GSMCATUSER',
# 'OLAPSYS', 'SI_INFORMTN_SCHEMA',
# 'OUTLN', 'ORDSYS', 'ORDDATA', 'OJVMSYS',
# 'ORACLE_OCM', 'MDSYS', 'ORDPLUGINS',
# 'GSMADMIN_INTERNAL', 'MDDATA', 'FLOWS_FILES',
# 'DIP', 'CTXSYS', 'AUDSYS',
# 'APPQOSSYS', 'APEX_PUBLIC_USER', 'ANONYMOUS',
# 'SPATIAL_CSW_ADMIN_USR', 'SYSKM',
# 'SYSMAN_TYPES', 'MGMT_VIEW',
# 'EUS_ENGINE_USER', 'EXFSYS', 'SYSMAN_APM'
# )
# )
# AND privilege NOT IN ('UNLIMITED TABLESPACE'
#                  , 'REFERENCES', 'INDEX', 'SYSDBA', 'SYSOPER'
# )
# ORDER  BY 1, 2;
# 
# If any administrative privileges have been assigned directly to a database account, this is a finding.
# 
# (The list of special accounts that are excluded from this requirement may not be complete.  It is expected that the DBA will edit the list to suit local circumstances, adding other special accounts as necessary, and removing any that are not supposed to be in use in the Oracle deployment that is under review.)
# 
# Create roles for administrative function assignments. Assign the necessary privileges for the administrative functions to a role.  Do not assign administrative privileges directly to users, except for those that Oracle does not permit to be assigned via roles.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::administrative_privileges_must_be_assigned_to_database_accounts_via_database_roles: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::administrative_privileges_must_be_assigned_to_database_accounts_via_database_roles::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `administrative_privileges_must_be_assigned_to_database_accounts_via_database_roles` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61591
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::administrative_privileges_must_be_assigned_to_database_accounts_via_database_roles
{
  ora_secured_setup { "administrative_privileges_must_be_assigned_to_database_accounts_via_database_roles on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
