#
# ora_secured::controls::admins_must_utilize_a_separate_distinct_administrative_accnt_when_performing_administrative_act_a
#
# @summary Review permissions for objects owned by DBA or other administrative accounts.
# If any objects owned by administrative accounts can be accessed by non-DBA/non-administrative users, either directly or indirectly, this is a finding.
# 
# Verify DBAs have separate administrative accounts.
# 
# If DBAs do not have a separate account for database administration purposes, this is a finding.
# 
# To list all objects owned by an administrative account that have had access granted to another account, run the query:
# 
# SELECT grantee, table_name, grantor, privilege, type from dba_tab_privs where owner= '<applicable account>';
# 
# 
# Revoke DBA privileges, and privileges to administer DBA-owned objects, from non-DBA accounts.
# 
# Provide separate accounts to DBA for database administration.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::admins_must_utilize_a_separate_distinct_administrative_accnt_when_performing_administrative_act_a: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::admins_must_utilize_a_separate_distinct_administrative_accnt_when_performing_administrative_act_a::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `admins_must_utilize_a_separate_distinct_administrative_accnt_when_performing_administrative_act_a` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61593
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::admins_must_utilize_a_separate_distinct_administrative_accnt_when_performing_administrative_act_a
{
  ora_secured_setup { "admins_must_utilize_a_separate_distinct_administrative_accnt_when_performing_administrative_act_a on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
