#
# ora_secured::controls::allocate_audit_record_storage_capacity_in_acc_with_org_def_audit_record_storage_reqs
#
# @summary Review the DBMS settings to determine whether audit logging is configured to produce logs consistent with the amount of space allocated for logging.
# If auditing will generate excessive logs so that they may outgrow the space reserved for logging, this is a finding.
# 
# If file-based auditing is in use, check that sufficient space is available to support the file(s). If not, this is a finding.
# 
# If standard, table-based auditing is used, the audit logs are written to a table called AUD$; and if a Virtual Private Database is deployed, a table is created called FGA_LOG$. First, check the current location of the audit trail tables.
# 
# CONN / AS SYSDBA
# 
# SELECT table_name, tablespace_name
# FROM dba_tables
# WHERE table_name IN ('AUD$', 'FGA_LOG$')
# ORDER BY table_name;
# 
# TABLE_NAME TABLESPACE_NAME
# ------------------------------ ------------------------------
# AUD$ SYSTEM
# FGA_LOG$ SYSTEM
# 
# If the tablespace name is SYSTEM, the table needs to be relocated to its own tablespace. Ensure that adequate space is allocated to that tablespace.
# 
# If Unified Auditing is used:
# Audit logs are written to tables in the AUDSYS schema. The default tablespace for AUDSYS is USERS. A separate tablespace should be created to contain audit data. Ensure that adequate space is allocated to that tablespace.
# Investigate whether there have been any incidents where the DBMS ran out of audit log space since the last time the space was allocated or other corrective measures were taken. If there have been, this is a finding.
# 
# Allocate sufficient audit file/table space to support peak demand.
# 
# Ensure that audit tables are in their own tablespaces and that the tablespaces have enough room for the volume of log data that will be produced.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::allocate_audit_record_storage_capacity_in_acc_with_org_def_audit_record_storage_reqs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::allocate_audit_record_storage_capacity_in_acc_with_org_def_audit_record_storage_reqs::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `allocate_audit_record_storage_capacity_in_acc_with_org_def_audit_record_storage_reqs` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61853
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::allocate_audit_record_storage_capacity_in_acc_with_org_def_audit_record_storage_reqs
{
  ora_secured_setup { "allocate_audit_record_storage_capacity_in_acc_with_org_def_audit_record_storage_reqs on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
