#
# ora_secured::controls::allow_designated_org_personnel_to_select_which_auditable_events_are_to_be_audited_by_db
#
# @summary Check DBMS settings and documentation to determine whether designated personnel are able to select which auditable events are being audited.
# If designated personnel are not able to configure auditable events, this is a finding.
# 
# Configure the DBMS's settings to allow designated personnel to select which auditable events are audited.
# 
# Note the following:
# In Oracle, any user can configure auditing for the objects in his or her own schema by using the AUDIT statement. To undo the audit configuration for an object, the user can use the NOAUDIT statement. No additional privileges are needed to perform this task.
# 
# To audit objects in another schema, the user must have the AUDIT ANY system privilege.
# To audit system privileges, the user must have the AUDIT SYSTEM privilege.
# 
# For more information on the configuration of auditing, refer to the following documents:
# "Auditing Database Activity" in the Oracle Database 2 Day + Security Guide:
# http://docs.oracle.com/database/121/TDPSG/tdpsg_auditing.htm#TDPSG50000
# "Monitoring Database Activity with Auditing" in the Oracle Database Security Guide:
# http://docs.oracle.com/database/121/DBSEG/part_6.htm#CCHEHCGI
# "DBMS_AUDIT_MGMT" in the Oracle Database PL/SQL Packages and Types Reference:
# http://docs.oracle.com/database/121/ARPLS/d_audit_mgmt.htm#ARPLS241
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::allow_designated_org_personnel_to_select_which_auditable_events_are_to_be_audited_by_db: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::allow_designated_org_personnel_to_select_which_auditable_events_are_to_be_audited_by_db::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `allow_designated_org_personnel_to_select_which_auditable_events_are_to_be_audited_by_db` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61623
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::allow_designated_org_personnel_to_select_which_auditable_events_are_to_be_audited_by_db
{
  ora_secured_setup { "allow_designated_org_personnel_to_select_which_auditable_events_are_to_be_audited_by_db on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
