#
# ora_secured::controls::alter_system_audit_option_is_enabled
#
# @summary `ALTER SYSTEM` allows one to change instance settings, including security settings
# and auditing options. Additionally, `ALTER SYSTEM` can be used to run operating
# system commands using undocumented Oracle functionality. Enabling the audit
# option will audit all attempts to perform `ALTER SYSTEM`, whether successful or
# not and regardless of whether or not the `ALTER SYSTEM` privilege is held by the
# user attempting the action.
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::alter_system_audit_option_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::alter_system_audit_option_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `alter_system_audit_option_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.1.16
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.1.16
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.1.16
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::alter_system_audit_option_is_enabled()
{
  $sid = $title
  ora_secured_setup { "alter_system_audit_option_is_enabled on ${sid}":
    ensure => 'present',
  }
  -> ora_secured::internal::audit_option{"ALTER SYSTEM@${sid}": }
}
