#
# ora_secured::controls::application_owner_accounts_must_have_a_dedicated_application_tablespace
#
# @summary Run the SQL query:
# select distinct owner, tablespace_name
# from dba_SEGMENTS 
# where owner not in
# (<list of non-applicable accounts>)
# order by tablespace_name;
# 
# (With respect to the list of special accounts that are excluded from this requirement, it is expected that the DBA will maintain the list to suit local circumstances, adding special accounts as necessary and removing any that are not supposed to be in use in the Oracle deployment that is under review.)
# 
# Review the list of returned table owners with the tablespace used.
# 
# If any of the owners listed are not default Oracle accounts and use the SYSTEM or any other tablespace not dedicated for the application’s use, this is a finding.
# 
# Look for multiple applications that may share a tablespace.
# 
# If no records were returned, ask the DBA if any applications use this database.
# 
# If no applications use the database, this is not a finding.
# 
# If there are applications that do use the database or if the application uses the SYS or other default account and SYSTEM tablespace to store its objects, this is a finding.
# 
# Create and assign dedicated tablespaces for the storage of data by each application using the CREATE TABLESPACE command.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::application_owner_accounts_must_have_a_dedicated_application_tablespace: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::application_owner_accounts_must_have_a_dedicated_application_tablespace::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `application_owner_accounts_must_have_a_dedicated_application_tablespace` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61461
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::application_owner_accounts_must_have_a_dedicated_application_tablespace
{
  ora_secured_setup { "application_owner_accounts_must_have_a_dedicated_application_tablespace on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
