#
# ora_secured::controls::application_role_permissions_must_not_be_assigned_to_the_oracle_public_role
#
# @summary From SQL*Plus:
# select granted_role from dba_role_privs where grantee = 'PUBLIC';
# 
# If any roles are listed, this is a finding.
# 
# Revoke role grants from PUBLIC.
# 
# Do not assign role privileges to PUBLIC.
# 
# 
#   revoke [role name] from PUBLIC;
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::application_role_permissions_must_not_be_assigned_to_the_oracle_public_role: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::application_role_permissions_must_not_be_assigned_to_the_oracle_public_role::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `application_role_permissions_must_not_be_assigned_to_the_oracle_public_role` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61443
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::application_role_permissions_must_not_be_assigned_to_the_oracle_public_role
{
  ora_secured_setup { "application_role_permissions_must_not_be_assigned_to_the_oracle_public_role on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
