#
# ora_secured::controls::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended
#
# @summary The `audit_trail` setting determines whether or not Oracle's basic audit features
# are enabled. It can be set to "Operating System"(OS); `DB; DB,EXTENDED`; `XML`; or
# `XML,EXTENDED`. The value should be set according to the needs of the
# organization.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.2
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Any] preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended(
  Any $preferred_value = ora_secured::lookup_setting('preferred_value',['XML','EXTENDED']),
){
  $sid = $title
  $unique = ora_secured::random_id(6)

  ora_secured_setup { "audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::parameter { "AUDIT_TRAIL@${sid}@${unique}":
    value => $preferred_value,
  }
}
