#
# ora_secured::controls::autom_term_emergency_accnts_after_an_org_def_time_period_for_each_type_of_accnt
#
# @summary If the organization has a policy, consistently enforced, forbidding the creation of emergency or temporary accounts, this is not a finding.
# Check DBMS settings, OS settings, and/or enterprise-level authentication/access mechanisms settings to determine if emergency accounts are being automatically terminated by the system after an organization-defined time period. Check also for custom code (scheduled jobs, procedures, triggers, etc.) for achieving this. 
# 
# If emergency accounts are not being terminated after an organization-defined time period, this is a finding.
# 
# Create a profile specifically for emergency or temporary accounts.  When creating the accounts, assign them to this profile.  Configure DBMS, OS, and/or enterprise-level authentication/access mechanisms, or implement custom code, to terminate accounts with this profile after an organization-defined time period.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::autom_term_emergency_accnts_after_an_org_def_time_period_for_each_type_of_accnt: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::autom_term_emergency_accnts_after_an_org_def_time_period_for_each_type_of_accnt::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `autom_term_emergency_accnts_after_an_org_def_time_period_for_each_type_of_accnt` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61777
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::autom_term_emergency_accnts_after_an_org_def_time_period_for_each_type_of_accnt
{
  ora_secured_setup { "autom_term_emergency_accnts_after_an_org_def_time_period_for_each_type_of_accnt on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
