#
# ora_secured::controls::database_must_not_be_directly_accessible_from_public_or_unauthorized_networks
#
# @summary Review the System Security Plan to determine if the DBMS serves data to users or applications outside the local enclave.
# If the DBMS is not accessed outside of the local enclave, this check is not a finding.
# 
# If the DBMS serves applications available from a public network (e.g. the Internet), then confirm that the application servers are located in a DMZ.
# 
# If the DBMS is located inside the local enclave and is directly accessible to public users, this is a finding.
# 
# If the DBMS serves public-facing applications and is not protected from direct client connections and unauthorized networks, this is a finding.
# 
# If the DBMS serves public-facing applications and contains sensitive or classified information, this is a finding.
# 
# Do not allow direct connections from users originating from the Internet or other public network to the DBMS.
# 
# Include in the System Security Plan for the system whether the DBMS serves public-facing applications or applications serving users from other untrusted networks.
# 
# Do not store sensitive or classified data on a DBMS server that serves public-facing applications.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::database_must_not_be_directly_accessible_from_public_or_unauthorized_networks: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::database_must_not_be_directly_accessible_from_public_or_unauthorized_networks::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_must_not_be_directly_accessible_from_public_or_unauthorized_networks` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61495
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::database_must_not_be_directly_accessible_from_public_or_unauthorized_networks
{
  ora_secured_setup { "database_must_not_be_directly_accessible_from_public_or_unauthorized_networks on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
