#
# ora_secured::controls::database_objects_must_be_owned_by_accounts_authorized_for_ownership
#
# @summary Review system documentation to identify accounts authorized to own database objects.
# Review accounts in DBMS that own objects.
# 
# If any database objects are found to be owned by users not authorized to own database objects, this is a finding.
# 
# - - - - -
# Query the object DBA_OBJECTS to show the users who own objects in the database.  The query below will return all of the users who own objects.
# 
# sqlplus connect as sysdba
# 
# SQL>select owner, object_type, count(*) from dba_objects
# group by owner, object_type
# order by owner, object_type;
# 
# If these owners are not authorized owners, select all of the objects these owners have generated and decide who they should belong to.  To make a list of all of the objects, the unauthorized owner has to perform the following query.
# 
# SQL>select * from dba_objects where owner =&unauthorized_owner;
# 
# Update system documentation to include list of accounts authorized for object ownership.
# 
# Re-assign ownership of authorized objects to authorized object owner accounts.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::database_objects_must_be_owned_by_accounts_authorized_for_ownership: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::database_objects_must_be_owned_by_accounts_authorized_for_ownership::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_objects_must_be_owned_by_accounts_authorized_for_ownership` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61673
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::database_objects_must_be_owned_by_accounts_authorized_for_ownership
{
  ora_secured_setup { "database_objects_must_be_owned_by_accounts_authorized_for_ownership on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
