#
# ora_secured::controls::db_sw_dirs_including_dbms_config_files_must_be_strd_in_dedicated_dirs_or_dasd_pools_separate_frm
#
# @summary Review the DBMS software library directory and note other root directories located on the same disk directory or any subdirectories.
# If any non-DBMS software directories exist on the disk directory, examine or investigate their use.
# 
# If any of the directories are used by other applications, including third-party applications that use the DBMS, this is a finding.
# 
# Only applications that are required for the functioning and administration, not use, of the DBMS should be located on the same disk directory as the DBMS software libraries.
# 
# For databases located on mainframes, confirm that the database and its configuration files are isolated in their own DASD pools.
# 
# If database software and database configuration files share DASD with other applications, this is a finding.
# 
# Install all applications on directories, or pools, separate from the DBMS software library directory. Re-locate any directories or re-install other application software that currently shares the DBMS software library directory to separate directories.
# 
# For mainframe-based databases, locate database software and configuration files in separate DASD pools from other mainframe applications.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::db_sw_dirs_including_dbms_config_files_must_be_strd_in_dedicated_dirs_or_dasd_pools_separate_frm: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::db_sw_dirs_including_dbms_config_files_must_be_strd_in_dedicated_dirs_or_dasd_pools_separate_frm::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `db_sw_dirs_including_dbms_config_files_must_be_strd_in_dedicated_dirs_or_dasd_pools_separate_frm` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61875
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::db_sw_dirs_including_dbms_config_files_must_be_strd_in_dedicated_dirs_or_dasd_pools_separate_frm
{
  ora_secured_setup { "db_sw_dirs_including_dbms_config_files_must_be_strd_in_dedicated_dirs_or_dasd_pools_separate_frm on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
