#
# ora_secured::controls::dbms_backup_and_restoration_files_must_be_protected_from_unauthorized_access
#
# @summary Review file protections assigned to online backup and restoration files.
# Review access protections and procedures for off-line backup and restoration files.
# 
# If backup or restoration files are subject to unauthorized access, this is a finding.
# 
# It may be necessary to review backup and restoration procedures to determine ownership and access during all phases of backup and recovery.
# 
# Implement protection for backup and restoration files. Document personnel and the level of access authorized for each to the backup and restoration files in the system documentation.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_backup_and_restoration_files_must_be_protected_from_unauthorized_access: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_backup_and_restoration_files_must_be_protected_from_unauthorized_access::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_backup_and_restoration_files_must_be_protected_from_unauthorized_access` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61699
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_backup_and_restoration_files_must_be_protected_from_unauthorized_access
{
  ora_secured_setup { "dbms_backup_and_restoration_files_must_be_protected_from_unauthorized_access on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
