#
# ora_secured::controls::dbms_data_files_transaction_logs_and_audit_files_must_be_strd_in_dedicated_dirs_or_disk_partition
#
# @summary Review the disk/directory specification where database data, transaction log and audit files are stored.
# If DBMS data, transaction log or audit data files are stored in the same directory, this is a finding.
# 
# If multiple applications are accessing the database and the database data files are stored in the same directory, this is a finding.
# 
# If multiple applications are accessing the database and database data is separated into separate physical directories according to application, this check is not a finding.
# 
# 
# Specify dedicated host system disk directories to store database data, transaction and audit files.
# Example directory structure:
# /*/app/oracle/oradata/db_name
# /*/app/oracle/admin/db_name/arch/*
# /*/app/oracle/oradata/db_name/audit
# /*/app/oracle/fast_recovery_area/db_name/
# 
# See Oracle Optimal Flexible Architecture:
# https://docs.oracle.com/database/121/LADBI/appendix_ofa.htm#LADBI7921
# 
# When multiple applications are accessing a single database, configure DBMS default file storage according to application to use dedicated disk directories. 
# 
# /*/app/oracle/oradata/db_name/app_name
# 
# See Oracle Optimal Flexible Architecture:
# https://docs.oracle.com/database/121/LADBI/appendix_ofa.htm#LADBI7921
# 
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_data_files_transaction_logs_and_audit_files_must_be_strd_in_dedicated_dirs_or_disk_partition: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_data_files_transaction_logs_and_audit_files_must_be_strd_in_dedicated_dirs_or_disk_partition::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_data_files_transaction_logs_and_audit_files_must_be_strd_in_dedicated_dirs_or_disk_partition` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61963
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_data_files_transaction_logs_and_audit_files_must_be_strd_in_dedicated_dirs_or_disk_partition
{
  ora_secured_setup { "dbms_data_files_transaction_logs_and_audit_files_must_be_strd_in_dedicated_dirs_or_disk_partition on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
