#
# ora_secured::controls::dbms_default_accounts_must_be_protected_from_misuse
#
# @summary Review the use of the essential system accounts with the DBA(s).
# Request evidence that administrators have individual administrative accounts and that they use these rather than SYS, SYSTEM, SYSMAN, etc., in carrying out their duties.
# 
# If the evidence indicates otherwise, this is a finding.
# 
# Review the status of the essential system accounts, in the view DBA_USERS.  If any of these accounts is not locked, or is not documented as a requirement, this is a finding.
# 
# Ensure that all individuals with DBA responsibilities always log on under their individual administrative accounts.
# 
# Ensure that the passwords for essential system accounts such as SYS are available only to authorized administrators and tightly guarded to avoid misuse.  Ensure that these accounts are kept locked except when it is specifically necessary to use them.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_default_accounts_must_be_protected_from_misuse: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_default_accounts_must_be_protected_from_misuse::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_default_accounts_must_be_protected_from_misuse` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61849
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_default_accounts_must_be_protected_from_misuse
{
  ora_secured_setup { "dbms_default_accounts_must_be_protected_from_misuse on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
