#
# ora_secured::controls::dbms_utlzng_dac_must_enforce_a_policy_that_incl_or_excl_acc_to_granularity_of_a_single_user
#
# @summary Check DBMS settings and documentation to determine if users are able to assign and revoke rights to the objects and information they own.
# If users cannot assign or revoke rights to the objects and information they own to the granularity of a single user, this is a finding.
# 
# (This is default Oracle behavior.)
# 
# Modify DBMS settings to allow users to assign or revoke access rights to objects and information owned by the user. The ability to grant or revoke rights must include the ability to grant or revoke those rights down to the granularity of a single user.
# 
# (This is default Oracle behavior.)
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbms_utlzng_dac_must_enforce_a_policy_that_incl_or_excl_acc_to_granularity_of_a_single_user: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbms_utlzng_dac_must_enforce_a_policy_that_incl_or_excl_acc_to_granularity_of_a_single_user::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbms_utlzng_dac_must_enforce_a_policy_that_incl_or_excl_acc_to_granularity_of_a_single_user` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61619
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbms_utlzng_dac_must_enforce_a_policy_that_incl_or_excl_acc_to_granularity_of_a_single_user
{
  ora_secured_setup { "dbms_utlzng_dac_must_enforce_a_policy_that_incl_or_excl_acc_to_granularity_of_a_single_user on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
