#
# ora_secured::controls::dbs_utlzng_dac_must_enforce_a_policy_that_lmts_propagation_of_acc_rights
#
# @summary Verify the DBMS has the ability to grant permissions without the grantee receiving the right to grant those same permissions to another user.
# Review organization policies regarding access propagation. If an access propagation policy limiting the propagation of rights does not exist, this is a finding.
# 
# Review DBMS configuration to verify access propagation policies are enforced by the DBMS as configured. If the DBMS does not enforce the access propagation policy, this is a finding.
# 
# Create and document an access propagation policy that limits the propagation of rights.
# 
# Configure the DBMS to enforce the access propagation policy.
# 
# When a user is granted access to an object, they have access to the object.  When a user is granted access to an object with the GRANT option, then they can provide permissions to others.  Without the GRANT option, a user cannot grant access to an object.  No configuration is required.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dbs_utlzng_dac_must_enforce_a_policy_that_lmts_propagation_of_acc_rights: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dbs_utlzng_dac_must_enforce_a_policy_that_lmts_propagation_of_acc_rights::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dbs_utlzng_dac_must_enforce_a_policy_that_lmts_propagation_of_acc_rights` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61617
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dbs_utlzng_dac_must_enforce_a_policy_that_lmts_propagation_of_acc_rights
{
  ora_secured_setup { "dbs_utlzng_dac_must_enforce_a_policy_that_lmts_propagation_of_acc_rights on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
