#
# ora_secured::controls::diag_subdir_under_dir_assigned_to_diag_dest_parameter_must_be_prot_frm_unauth_acc
#
# @summary From SQL*Plus:
# select value from v$parameter where name='diagnostic_dest';
# 
# On UNIX Systems:
# 
# ls -ld [pathname]/diag
# 
# Substitute [pathname] with the directory path listed from the above SQL command, and append "/diag" to it, as shown.
# 
# If permissions are granted for world access, this is a Finding.
# 
# If any groups that include members other than the Oracle process and software owner accounts, DBAs, auditors, or backup accounts are listed, this is a Finding.
# 
# On Windows Systems (From Windows Explorer):
# 
# Browse to the \diag directory under the directory specified.
# 
# Select and right-click on the directory, select Properties, select the Security tab.
# 
# If permissions are granted to everyone, this is a Finding.
# 
# If any account other than the Oracle process and software owner accounts, Administrators, DBAs, System group or developers authorized to write and debug applications on this database are listed, this is a Finding.
# 
# Alter host system permissions to the <DIAGNOSTIC_DEST>/diag directory to the Oracle process and software owner accounts, DBAs, SAs (if required) and developers or other users that may specifically require access for debugging or other purposes.
# 
# Authorize and document user access requirements to the directory outside of the Oracle, DBA and SA account list.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::diag_subdir_under_dir_assigned_to_diag_dest_parameter_must_be_prot_frm_unauth_acc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::diag_subdir_under_dir_assigned_to_diag_dest_parameter_must_be_prot_frm_unauth_acc::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `diag_subdir_under_dir_assigned_to_diag_dest_parameter_must_be_prot_frm_unauth_acc` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61531
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::diag_subdir_under_dir_assigned_to_diag_dest_parameter_must_be_prot_frm_unauth_acc
{
  ora_secured_setup { "diag_subdir_under_dir_assigned_to_diag_dest_parameter_must_be_prot_frm_unauth_acc on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
