#
# ora_secured::controls::dir_assigned_to_audit_file_dest_parameter_must_be_prot_frm_unauth_acc_and_must_be_strd_in_a_dedic
#
# @summary If Standard Auditing is used:
# From SQL*Plus:
# 
# select value from v$parameter where name = 'audit_trail';
# select value from v$parameter where name = 'audit_file_dest';
# 
# If audit_trail is NOT set to OS, XML or XML EXTENDED, this is not applicable (NA).
# 
# If audit_trail is set to OS, but the audit records are routed directly to a separate log server without writing to the local file system, this is not a finding.
# 
# On UNIX Systems:
# 
# ls -ld [pathname]
# 
# Replace [pathname] with the directory path listed from the above SQL command for audit_file_dest.
# 
# If permissions are granted for world access, this is a finding.
# 
# If any groups that include members other than the Oracle process and software owner accounts, DBAs, auditors, or backup accounts are listed, this is a finding.
# 
# Compare path to $ORACLE_HOME. If audit_file_dest is a subdirectory of $ORACLE_HOME, this is a finding.
# 
# On Windows Systems (From Windows Explorer):
# 
# Browse to the directory specified. Select and right-click on the directory, select Properties, select the Security tab. On Windows hosts, records are also written to the Windows application event log. The location of the application event log is listed under Properties for the log under the Windows console. The default location is C:\WINDOWS\system32\config\EventLogs\AppEvent.Evt.
# 
# If permissions are granted to everyone, this is a finding. If any accounts other than the Administrators, DBAs, System group, auditors or backup operators are listed, this is a finding.
# 
# Compare path to %ORACLE_HOME%. If audit_file_dest is a subdirectory of %ORACLE_HOME%, this is a finding.
# 
# If Unified Auditing is used:
# AUDIT_FILE_DEST parameter is not used in Unified Auditing
# 
# For file-based auditing, establish an audit file directory separate from the Oracle Home.
# 
# Alter host system permissions to the AUDIT_FILE_DEST directory to the Oracle process and software owner accounts, DBAs, backup accounts, SAs (if required), and auditors.
# 
# Authorize and document user access requirements to the directory outside of the Oracle, DBA, and SA account list in the System Security Plan.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dir_assigned_to_audit_file_dest_parameter_must_be_prot_frm_unauth_acc_and_must_be_strd_in_a_dedic: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dir_assigned_to_audit_file_dest_parameter_must_be_prot_frm_unauth_acc_and_must_be_strd_in_a_dedic::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dir_assigned_to_audit_file_dest_parameter_must_be_prot_frm_unauth_acc_and_must_be_strd_in_a_dedic` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61965
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dir_assigned_to_audit_file_dest_parameter_must_be_prot_frm_unauth_acc_and_must_be_strd_in_a_dedic
{
  ora_secured_setup { "dir_assigned_to_audit_file_dest_parameter_must_be_prot_frm_unauth_acc_and_must_be_strd_in_a_dedic on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
