#
# ora_secured::controls::dirs_assigned_to_log_archive_dest_parameters_must_be_prot_frm_unauth_acc
#
# @summary From SQL*Plus:
# select log_mode from v$database;
#   select value from v$parameter where name = 'log_archive_dest';
#   select value from v$parameter where name = 'log_archive_duplex_dest';
#   select name, value from v$parameter where name LIKE 'log_archive_dest_%';
#   select value from v$parameter where name = 'db_recovery_file_dest';
# 
# If the value returned for LOG_MODE is NOARCHIVELOG, this check is not a finding.
# 
# If a value is not returned for LOG_ARCHIVE_DEST and no values are returned for any of the LOG_ARCHIVE_DEST_[1-10] parameters, and no value is returned for DB_RECOVERY_FILE_DEST, this is a finding.
# 
# Note: LOG_ARCHIVE_DEST and LOG_ARCHIVE_DUPLEX_DEST are incompatible with the LOG_ARCHIVE_DEST_n parameters, and must be defined as the null string (' ') when any LOG_ARCHIVE_DEST_n parameter has a value other than a null string.
# 
# On UNIX Systems:
# 
#   ls -ld [pathname]
# 
# Substitute [pathname] with the directory paths listed from the above SQL statements for log_archive_dest and log_archive_duplex_dest.
# 
# If permissions are granted for world access, this is a finding.
# 
# On Windows Systems (From Windows Explorer):
# 
# Browse to the directory specified.
# 
# Select and right-click on the directory, select Properties, select the Security tab.
# 
# If permissions are granted to everyone, this is a finding.
# 
# If any account other than the Oracle process and software owner accounts, Administrators, DBAs, System group or developers authorized to write and debug applications on this database are listed, this is a finding.
# 
# Specify a valid and protected directory for archive log files.
# 
# Restrict access to the Oracle process and software owner accounts, DBAs, and backup operator accounts.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dirs_assigned_to_log_archive_dest_parameters_must_be_prot_frm_unauth_acc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dirs_assigned_to_log_archive_dest_parameters_must_be_prot_frm_unauth_acc::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dirs_assigned_to_log_archive_dest_parameters_must_be_prot_frm_unauth_acc` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61463
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dirs_assigned_to_log_archive_dest_parameters_must_be_prot_frm_unauth_acc
{
  ora_secured_setup { "dirs_assigned_to_log_archive_dest_parameters_must_be_prot_frm_unauth_acc on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
