#
# ora_secured::controls::employ_automated_mechanisms_for_supporting_oracle_user_account_management
#
# @summary If all user accounts are authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, this is not a finding.
# If an Oracle feature/product, an OS feature, a third-party product, or custom code is used to automate account management, this is not a finding.
# 
# Determine what the site-defined definition of an acceptably small level of manual account-management activity is.  If the site has established the definition, documented it, and obtained ISSO-ISSM-AO approval, use that definition.  If not, use the following rule of thumb as the definition:  no more than 12 such accounts exist or are expected to exist; no more than 100 manual account-management actions (account creation, modification, locking, unlocking, removal and the like) are expected to occur in the course of a year.
# 
# If the amount of account management activity is small, as defined in the preceding paragraph, this is not a finding.
# 
# Otherwise, this is a finding.
# 
# Utilize an Oracle feature/product, an OS feature, a third-party product, or custom code to automate some or all account maintenance functionality.
# 
# - - - - -
# 
# Roles and Profiles are two Oracle features that should be employed in account management. (Indeed, other requirements mandate the use of Roles.) Following are some notes from Oracle on the use of Profiles.
# 
# A profile is a named set of resource limits and password parameters that restrict database usage and instance resources for a user. You can assign a profile to each user, and a default profile to all others. Each user can have only one profile, and creating a new one supersedes any earlier one.
# 
# Profile resource limits are enforced only when you enable resource limitation for the associated database. Enabling such limitation can occur either before starting up the database (the RESOURCE_LIMIT initialization parameter) or while it is open (using an ALTER SYSTEM statement).
# 
# While password parameters reside in profiles, they are unaffected by RESOURCE_LIMIT or ALTER SYSTEM and password management is always enabled.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::employ_automated_mechanisms_for_supporting_oracle_user_account_management: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::employ_automated_mechanisms_for_supporting_oracle_user_account_management::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `employ_automated_mechanisms_for_supporting_oracle_user_account_management` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61557
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::employ_automated_mechanisms_for_supporting_oracle_user_account_management
{
  ora_secured_setup { "employ_automated_mechanisms_for_supporting_oracle_user_account_management on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
