#
# ora_secured::controls::employ_strong_ident_and_auth_techs_when_esting_nonlocal_maint_and_diag_sess
#
# @summary Review DBMS settings to determine whether strong identification and authentication techniques are required for nonlocal maintenance and diagnostic sessions.
# If strong identification and authentication techniques are not required, this is a finding.
# 
# Configure DBMS settings to use strong identification and authentication techniques for nonlocal maintenance and diagnostic sessions.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::employ_strong_ident_and_auth_techs_when_esting_nonlocal_maint_and_diag_sess: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::employ_strong_ident_and_auth_techs_when_esting_nonlocal_maint_and_diag_sess::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `employ_strong_ident_and_auth_techs_when_esting_nonlocal_maint_and_diag_sess` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61751
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::employ_strong_ident_and_auth_techs_when_esting_nonlocal_maint_and_diag_sess
{
  ora_secured_setup { "employ_strong_ident_and_auth_techs_when_esting_nonlocal_maint_and_diag_sess on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
