#
# ora_secured::controls::fixed_user_and_public_database_links_must_be_authorized_for_use
#
# @summary From SQL*Plus:
# select owner||': '||db_link from dba_db_links;
# 
# If no records are returned from the first SQL statement, this check is not a finding.
# 
# Confirm the public and fixed user database links listed are documented in the System Security Plan, are authorized by the ISSO, and are used for replication or operational system requirements.
# 
# If any are not, this is a finding.
# 
# 
# Document all authorized connections from the database to remote databases in the System Security Plan.
# 
# Remove all unauthorized remote database connection definitions from the database.
# 
# 
#   drop database link [link name];
# OR
#   drop public database link [link name];
# 
# Review remote database connection definitions periodically and confirm their use is still required and authorized.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::fixed_user_and_public_database_links_must_be_authorized_for_use: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::fixed_user_and_public_database_links_must_be_authorized_for_use::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `fixed_user_and_public_database_links_must_be_authorized_for_use` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61415
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::fixed_user_and_public_database_links_must_be_authorized_for_use
{
  ora_secured_setup { "fixed_user_and_public_database_links_must_be_authorized_for_use on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
