#
# ora_secured::controls::implement_required_cryptographic_protions_using_cryptographic_modules_complying_with_applicable_f
#
# @summary If encryption is not required for the database, this is not a finding.
# If the DBMS has not implemented federally required cryptographic protections for the level of classification of the data it contains, this is a finding.
# 
# Check the following settings to see if FIPS 140-2 encryption is configured. If encryption is not configured, check with the DBA and SYSTEM Administrator to see if other mechanisms or third-party products are deployed to encrypt data during the transmission or storage of data.
# 
# For Transparent Data Encryption and DBMS_CRYPTO:
# 
# To see if Oracle is configured for FIPS 140-2 Transparent Data Encryption and/or DBMS_CRYPTO, enter the following SQL*Plus command:
# SHOW PARAMETER DBFIPS_140
# or the following SQL query:
# SELECT * FROM SYS.V$PARAMETER WHERE NAME = 'DBFIPS_140';
# 
# If Oracle returns the value 'FALSE', or returns no rows, this is a finding.
# 
# To see if Oracle is configured for FIPS 140-2 SSL/TLS authentication and/or Encryption:
# 
# Verify the DBMS version:
# select * from V_$VERSION;
# 
# If the version displayed for Oracle Database is lower than 12.1.0.2, this is a finding.
# 
# If the operating system is Windows and the DBMS version is 12.1.0.2, use the opatch command to display the patches applied to the DBMS.
# 
# If the patches listed do not include "WINDOWS DB BUNDLE PATCH 12.1.0.2.7", this is a finding.
# 
# Open the fips.ora file in a browser or editor.  (The default location for fips.ora is $ORACLE_HOME/ldap/admin/ but alternate locations are possible. An alternate location, if it is in use, is specified in the FIPS_HOME environment variable.)
# 
# If the line "SSLFIPS_140=TRUE" is not found in fips.ora, or the file does not exist, this is a finding.
# 
# For (Native) Network Data Encryption:
# If the line, SQLNET.FIPS_140=TRUE is not found in $ORACLE_HOME/network/admin/sqlnet.ora, this is a finding. (Note: This assumes that a single sqlnet.ora file, in the default location, is in use. Please see the supplemental file "Non-default sqlnet.ora configurations.pdf" for how to find multiple and/or differently located sqlnet.ora files.)
# 
# Note: For the Solaris platform, when DBFIPS_140 is FALSE, TDE (but not DBMS_CRYPTO) can still operate in a FIPS 140-compliant manner if FIPS 140 operation is enabled for the Solaris Cryptographic Framework.
# 
# Implement required cryptographic protections using cryptographic modules complying with applicable federal laws, Executive Orders, directives, policies, regulations, standards, and guidance.
# 
# Where not already in effect, upgrade the DBMS to version 12.1.0.2 or higher.
# 
# Where the operating system is Windows and the DBMS version is 12.1.0.2, install patch "WINDOWS DB BUNDLE PATCH 12.1.0.2.7" if not already deployed.
# 
# Open the fips.ora file in an editor.  (The default location for fips.ora is $ORACLE_HOME/ldap/admin/ but alternate locations are possible. An alternate location, if it is in use, is specified in the FIPS_HOME environment variable.)
# 
# Create or modify fips.ora to include the line "SSLFIPS_140=TRUE".
# 
# - - - - -
# The strength requirements are dependent upon data classification.
# 
# For unclassified data, where cryptography is required:
# AES 128 for encryption
# SHA 256 for hashing
# 
# NSA has established the suite B encryption requirements for protecting National Security Systems (NSS) as follows:
# AES 128 for Secret
# AES 256 for Top Secret
# SHA 256 for Secret
# SHA 384 for Top Secret
# 
# National Security System is defined as:
# (OMB Circular A-130) Any telecommunications or information system operated by the United States Government, the function, operation, or use of which (1) involves intelligence activities; (2) involves cryptologic activities related to national security; (3) involves command and control of military forces; (4) involves equipment that is an integral part of a weapon or weapons system; or (5) is critical to the direct fulfillment of military or intelligence missions, but excluding any system that is to be used for routine administrative and business applications (including payroll, finance, logistics, and personnel management applications).
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::implement_required_cryptographic_protions_using_cryptographic_modules_complying_with_applicable_f: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::implement_required_cryptographic_protions_using_cryptographic_modules_complying_with_applicable_f::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `implement_required_cryptographic_protions_using_cryptographic_modules_complying_with_applicable_f` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61759
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::implement_required_cryptographic_protions_using_cryptographic_modules_complying_with_applicable_f
{
  ora_secured_setup { "implement_required_cryptographic_protions_using_cryptographic_modules_complying_with_applicable_f on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
