#
# ora_secured::controls::isolate_security_functions_from_nonsecurity_functions_by_means_of_separate_security_domains
#
# @summary Check DBMS settings to determine whether objects or code implementing security functionality are located in a separate security domain, such as a separate database or schema created specifically for security functionality.
# If security-related database objects or code are not kept separate, this is a finding.
# 
# The Oracle elements of security functionality, such as the roles, permissions, and profiles, along with password complexity requirements, are stored in separate schemas in the database.  Review any site-specific applications security modules built into the database and determine what schema they are located in and take appropriate action.  The Oracle objects will be in the Oracle Data Dictionary.
# 
# Locate security-related database objects and code in a separate database, schema, or other separate security domain from database objects and code implementing application logic.  (This is the default behavior for Oracle.)  Review any site-specific applications security modules built into the database:   determine what schema they are located in and take appropriate action.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::isolate_security_functions_from_nonsecurity_functions_by_means_of_separate_security_domains: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::isolate_security_functions_from_nonsecurity_functions_by_means_of_separate_security_domains::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `isolate_security_functions_from_nonsecurity_functions_by_means_of_separate_security_domains` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61775
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::isolate_security_functions_from_nonsecurity_functions_by_means_of_separate_security_domains
{
  ora_secured_setup { "isolate_security_functions_from_nonsecurity_functions_by_means_of_separate_security_domains on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
