#
# ora_secured::controls::lmt_number_of_concurrent_sess_for_each_sys_accnt_to_an_org_def_number_of_sess
#
# @summary Retrieve the settings for concurrent sessions for each profile with the query:
# SELECT * FROM SYS.DBA_PROFILES WHERE RESOURCE_NAME = 'SESSIONS_PER_USER';
# 
# If the DBMS settings for concurrent sessions for each profile are greater than the site-specific maximum number of sessions, this is a finding.
# 
# Limit concurrent connections for each system account to a number less than or equal to the organization-defined number of sessions using the following SQL. Create profiles that conform to the requirements. Assign users to the appropriate profile.
# 
# The user profile, ORA_STIG_PROFILE, has been provided (starting with Oracle 12.1.0.2) to satisfy the STIG requirements pertaining to the profile parameters. Oracle recommends that this profile be customized with any site-specific requirements and assigned to all users where applicable.  Note: It remains necessary to create a customized replacement for the password validation function, ORA12C_STRONG_VERIFY_FUNCTION, if relying on this technique to verify password complexity.
# 
# The defaults for ORA_STIG_PROFILE are set as follows:
# Resource Name                   Limit
# -------------                   ------
# COMPOSITE_LIMIT                 DEFAULT
# SESSIONS_PER_USER               DEFAULT
# CPU_PER_SESSION                 DEFAULT
# CPU_PER_CALL                    DEFAULT
# LOGICAL_READS_PER_SESSION       DEFAULT
# LOGICAL_READS_PER_CALL          DEFAULT
# IDLE_TIME                          15
# CONNECT_TIME                    DEFAULT
# PRIVATE_SGA                     DEFAULT
# FAILED_LOGIN_ATTEMPTS               3 
# PASSWORD_LIFE_TIME                 60
# PASSWORD_REUSE_TIME               365
# PASSWORD_REUSE_MAX                 10
# PASSWORD_VERIFY_FUNCTION    ORA12C_STRONG_VERIFY_FUNCTION
# PASSWORD_LOCK_TIME              UNLIMITED
# PASSWORD_GRACE_TIME                 5
# 
# Change the value of SESSIONS_PER_USER (along with the other parameters, where relevant) from UNLIMITED to DoD-compliant, site-specific requirements and then assign users to the profile.
# ALTER PROFILE ORA_STIG_PROFILE LIMIT SESSIONS_PER_USER <site-specific value>;
# 
# To assign the user to the profile do the following:
# ALTER USER <username> PROFILE ORA_STIG_PROFILE;
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::lmt_number_of_concurrent_sess_for_each_sys_accnt_to_an_org_def_number_of_sess: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::lmt_number_of_concurrent_sess_for_each_sys_accnt_to_an_org_def_number_of_sess::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `lmt_number_of_concurrent_sess_for_each_sys_accnt_to_an_org_def_number_of_sess` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61967
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::lmt_number_of_concurrent_sess_for_each_sys_accnt_to_an_org_def_number_of_sess
{
  ora_secured_setup { "lmt_number_of_concurrent_sess_for_each_sys_accnt_to_an_org_def_number_of_sess on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
