#
# ora_secured::controls::manage_resources_to_lmt_effects_of_info_flooding_types_of_denial_of_service_dos_incidents
#
# @summary Review Oracle user profiles.
# Connect to Oracle as SYSDBA. Use the following query to determine the established profiles and the users and resource limits assigned to them.
# 
# select a.username, a.profile, b.resource_name, b.resource_type, b.limit
# from dba_users a, dba_profiles b 
# where a.profile = b.profile and resource_type='KERNEL' 
# order by a.profile;
# 
# If the configuration does not include profile limits on resource-intensive SQL queries, or if users are not assigned to profiles appropriate to their needs, this is a finding.
# 
# Configure Oracle profile(s) to set resource limits appropriate to each class of user.
# 
# SESSIONS_PER_USER 
# Specify the number of concurrent sessions to which you want to limit the user.
# 
# CPU_PER_SESSION  
# Specify the CPU time limit for a session, expressed in hundredth of seconds.
# 
# CPU_PER_CALL  
# Specify the CPU time limit for a call (a parse, execute, or fetch), expressed in hundredths of seconds.
# 
# CONNECT_TIME 
# Specify the total elapsed time limit for a session, expressed in minutes.
# 
# IDLE_TIME 
# Specify the permitted periods of continuous inactive time during a session, expressed in minutes. Long-running queries and other operations are not subject to this limit.
# 
# LOGICAL_READS_PER_SESSION 
# Specify the permitted number of data blocks read in a session, including blocks read from memory and disk.
# 
# LOGICAL_READS_PER_CALL 
# Specify the permitted number of data blocks read for a call to process a SQL statement (a parse, execute, or fetch).
# 
# PRIVATE_SGA 
# Specify the amount of private space a session can allocate in the shared pool of the system global area (SGA). Refer to size_clause for information on that clause.
# 
# COMPOSITE_LIMIT
# (This limit applies only when using shared server architecture. The private space for a session in the SGA includes private SQL and PL/SQL areas, but not shared SQL and PL/SQL areas.) Specify the total resource cost for a session, expressed in service units. Oracle Database calculates the total service units as a weighted sum of CPU_PER_SESSION, CONNECT_TIME, LOGICAL_READS_PER_SESSION, and PRIVATE_SGA.
# 
# 
# The user profile, ORA_STIG_PROFILE, has been provided (starting with Oracle 12.1.0.2) to satisfy the STIG requirements pertaining to the profile parameters. Oracle recommends that this profile be customized with any site-specific requirements and assigned to all users where applicable.  Note: It remains necessary to create a customized replacement for the password validation function, ORA12C_STRONG_VERIFY_FUNCTION, if relying on this technique to verify password complexity.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::manage_resources_to_lmt_effects_of_info_flooding_types_of_denial_of_service_dos_incidents: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::manage_resources_to_lmt_effects_of_info_flooding_types_of_denial_of_service_dos_incidents::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `manage_resources_to_lmt_effects_of_info_flooding_types_of_denial_of_service_dos_incidents` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61817
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::manage_resources_to_lmt_effects_of_info_flooding_types_of_denial_of_service_dos_incidents
{
  ora_secured_setup { "manage_resources_to_lmt_effects_of_info_flooding_types_of_denial_of_service_dos_incidents on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
