#
# ora_secured::controls::map_the_authenticated_identity_to_the_user_account_using_pki_based_authentication
#
# @summary Review DBMS configuration to verify DBMS user accounts are being mapped directly to authenticated identity information being passed via the PKI.
# If user accounts are not being mapped to authenticated identity information being passed via the PKI, this is a finding.
# 
# - - - - -
# The database supports PKI-based authentication by using digital certificates over TLS in addition to the native encryption and data integrity capabilities of these protocols.
# 
# Oracle provides a complete PKI that is based on RSA Security, Inc., Public-Key Cryptography Standards, and which interoperates with Oracle servers and clients.  The database uses a wallet that is a container that is used to store authentication and signing credentials, including private keys, certificates, and trusted certificates needed by TLS. In an Oracle environment, every entity that communicates over TLS must have a wallet containing an X.509 version 3 certificate, private key, and list of trusted certificates.  Security administrators use Oracle Wallet Manager to manage security credentials on the server.
# 
# If the $ORACLE_HOME/network/admin/sqlnet.ora contains the following entries, TLS is installed. (Note: This assumes that a single sqlnet.ora file, in the default location, is in use. Please see the supplemental file "Non-default sqlnet.ora configurations.pdf" for how to find multiple and/or differently located sqlnet.ora files.)
# 
# WALLET_LOCATION = (SOURCE=
#                           (METHOD = FILE) 
#                           (METHOD_DATA = 
#                            DIRECTORY=/wallet) 
# 
# SSL_CIPHER_SUITES=(SSL_cipher_suiteExample) 
# SSL_VERSION = 1.2
# SSL_CLIENT_AUTHENTICATION=FALSE/TRUE
# 
# Configure the DBMS to map the authenticated identity directly to the DBMS user account.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::map_the_authenticated_identity_to_the_user_account_using_pki_based_authentication: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::map_the_authenticated_identity_to_the_user_account_using_pki_based_authentication::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `map_the_authenticated_identity_to_the_user_account_using_pki_based_authentication` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61743
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::map_the_authenticated_identity_to_the_user_account_using_pki_based_authentication
{
  ora_secured_setup { "map_the_authenticated_identity_to_the_user_account_using_pki_based_authentication on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
