#
# ora_secured::controls::minimum_of_two_orcl_control_files_must_be_def_and_configed_to_be_strd_on_separate_archived_disks
#
# @summary From SQL*Plus:
# select name from v$controlfile;
# 
# DoD guidance recommends:
# 
# 2a. Each control file is to be located on separate, archived physical or virtual storage devices.
# 
# OR
# 
# 2b. Each control file is to be located on separate, archived directories within one or more RAID devices. 
# 
# 3. The Logical Paths for each control file should differ at the highest level supported by the configuration, for example:
# 
# UNIX
# /ora03/app/oracle/{SID}/control/control01.ctl
# /ora04/app/oracle/{SID}/control/control02.ctl
# 
# Windows
# D:/oracle/{SID}/control/control01.ctl
# E:/oracle/{SID}/control/control02.ctl
# 
# If the minimum listed above is not met, this is a finding.
# 
# Consult with the SA or DBA to determine that the mount points or partitions referenced in the file paths indicate separate physical disks or directories on RAID devices.
# 
# Note: Distinct does not equal dedicated. May share directory space with other Oracle database instances if present.
# 
# To prevent loss of service during disk failure, multiple copies of Oracle control files must be maintained on separate disks in archived directories or on separate, archived directories within one or more RAID devices.
# 
# Adding or moving a control file requires careful planning and execution.
# 
# Consult and follow the instructions for creating control files in the Oracle Database Administrator's Guide, under Steps for Creating New Control Files.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::minimum_of_two_orcl_control_files_must_be_def_and_configed_to_be_strd_on_separate_archived_disks: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::minimum_of_two_orcl_control_files_must_be_def_and_configed_to_be_strd_on_separate_archived_disks::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `minimum_of_two_orcl_control_files_must_be_def_and_configed_to_be_strd_on_separate_archived_disks` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61417
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::minimum_of_two_orcl_control_files_must_be_def_and_configed_to_be_strd_on_separate_archived_disks
{
  ora_secured_setup { "minimum_of_two_orcl_control_files_must_be_def_and_configed_to_be_strd_on_separate_archived_disks on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
