#
# ora_secured::controls::notify_appropriate_individuals_when_accounts_are_terminated
#
# @summary Check DBMS settings to determine whether it will notify appropriate individuals when accounts are terminated.
# If the DBMS does not notify appropriate individuals when accounts are terminated, this is a finding.
# 
# Working with the DBA and site management, determine the appropriate individuals (by job role) to be notified.
# 
# If Oracle Audit Vault is available, configure it to notify the appropriate individuals when accounts are terminated.
# 
# If Oracle Audit Vault is not available, configure the Oracle DBMS's auditing feature to record termination of accounts.
# 
# If Standard Auditing is used:
# Create and deploy a mechanism, such as a frequently-run job, to monitor the SYS.AUD$ table for these records and notify the appropriate individuals.
# 
# If unified Auditing is used:
# Create and deploy a mechanism, such as a frequently-run job, to monitor the SYS.UNIFIED_AUDIT_TRAIL view for these records and notify the appropriate individuals.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::notify_appropriate_individuals_when_accounts_are_terminated: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::notify_appropriate_individuals_when_accounts_are_terminated::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `notify_appropriate_individuals_when_accounts_are_terminated` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61803
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::notify_appropriate_individuals_when_accounts_are_terminated
{
  ora_secured_setup { "notify_appropriate_individuals_when_accounts_are_terminated on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
