#
# ora_secured::controls::oracle_application_administration_roles_must_be_disabled_if_not_required_and_authorized
#
# @summary Run the SQL query:
# select grantee, granted_role from dba_role_privs
#   where default_role='YES'
#   and granted_role in
#   (select grantee from dba_sys_privs where upper(privilege) like '%USER%')  
#   and grantee not in
#   (<list of non-applicable accounts>)
#   and grantee not in (select distinct owner from dba_tables)
#   and grantee not in
#   (select distinct username from dba_users where upper(account_status) like
#    '%LOCKED%');
# 
# (With respect to the list of special accounts that are excluded from this requirement, it is expected that the DBA will maintain the list to suit local circumstances, adding special accounts as necessary and removing any that are not supposed to be in use in the Oracle deployment that is under review.)
# 
# Review the list of accounts reported for this check and ensures that they are authorized application administration roles.
# 
# If any are not authorized application administration roles, this is a finding.
# 
# For each role assignment returned, issue:
# 
# From SQL*Plus:
# 
#   alter user [username] default role all except [role];
# 
# If the user has more than one application administration role assigned, then remove assigned roles from default assignment and assign individually the appropriate default roles.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_application_administration_roles_must_be_disabled_if_not_required_and_authorized: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_application_administration_roles_must_be_disabled_if_not_required_and_authorized::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_application_administration_roles_must_be_disabled_if_not_required_and_authorized` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61445
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_application_administration_roles_must_be_disabled_if_not_required_and_authorized
{
  ora_secured_setup { "oracle_application_administration_roles_must_be_disabled_if_not_required_and_authorized on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
