#
# ora_secured::controls::oracle_remote_os_roles_parameter_must_be_set_to_false
#
# @summary From SQL*Plus:
# select value from v$parameter where name = 'remote_os_roles';
# 
# If the returned value is not FALSE or not documented in the System Security Plan as required, this is a finding.
# 
# Document remote OS roles in the System Security Plan.
# 
# If not required, disable use of remote OS roles.
# 
# 
#   alter system set remote_os_roles = FALSE scope = spfile;
# 
# The above SQL*Plus command will set the parameter to take effect at next system startup.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_remote_os_roles_parameter_must_be_set_to_false: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_remote_os_roles_parameter_must_be_set_to_false::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_remote_os_roles_parameter_must_be_set_to_false` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61427
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_remote_os_roles_parameter_must_be_set_to_false
{
  ora_secured_setup { "oracle_remote_os_roles_parameter_must_be_set_to_false on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
