#
# ora_secured::controls::oracle_sql92_security_parameter_must_be_set_to_true
#
# @summary From SQL*Plus:
# select value from v$parameter where name = 'sql92_security';
# 
# If the value returned is set to FALSE, this is a finding.
# 
# If the parameter is set to TRUE or does not exist, this is not a finding.
# 
# Enable SQL92 security.
# 
# 
#   alter system set sql92_security = TRUE scope = spfile;
# 
# The above SQL*Plus command will set the parameter to take effect at next system startup.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::oracle_sql92_security_parameter_must_be_set_to_true: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::oracle_sql92_security_parameter_must_be_set_to_true::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `oracle_sql92_security_parameter_must_be_set_to_true` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61429
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::oracle_sql92_security_parameter_must_be_set_to_true
{
  ora_secured_setup { "oracle_sql92_security_parameter_must_be_set_to_true on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
