#
# ora_secured::controls::orcl_db_must_off_load_audit_data_to_a_separate_log_mgmt_facility_this_must_be_continuous_and_in_n
#
# @summary Review the system documentation for a description of how audit records are off-loaded.
# If the DBMS has a continuous network connection to the centralized log management system, but the DBMS audit records are not written directly to the centralized log management system or transferred in near-real-time, this is a finding.
# 
# If the DBMS does not have a continuous network connection to the centralized log management system, and the DBMS audit records are not transferred to the centralized log management system weekly or more often, this is a finding.
# 
# Configure the DBMS or deploy and configure software tools to transfer audit records to a centralized log management system, continuously and in near-real-time where a continuous network connection to the log management system exists, or at least weekly in the absence of such a connection.
# 
# For more information on auditing, refer to the following documents:
# 
# https://docs.oracle.com/database/121/DBSEG/auditing.htm#DBSEG1024
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::orcl_db_must_off_load_audit_data_to_a_separate_log_mgmt_facility_this_must_be_continuous_and_in_n: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::orcl_db_must_off_load_audit_data_to_a_separate_log_mgmt_facility_this_must_be_continuous_and_in_n::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `orcl_db_must_off_load_audit_data_to_a_separate_log_mgmt_facility_this_must_be_continuous_and_in_n` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61871
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::orcl_db_must_off_load_audit_data_to_a_separate_log_mgmt_facility_this_must_be_continuous_and_in_n
{
  ora_secured_setup { "orcl_db_must_off_load_audit_data_to_a_separate_log_mgmt_facility_this_must_be_continuous_and_in_n on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
