#
# ora_secured::controls::orcl_pwd_file_ownership_and_permissions_should_be_lmted_and_rmt_login_pwdfile_parameter_must_be_s
#
# @summary From SQL*Plus:
# select value from v$parameter where upper(name) = 'REMOTE_LOGIN_PASSWORDFILE';
# 
# If the value returned does not equal 'EXCLUSIVE' or 'NONE', this is a finding.
# 
# On UNIX Systems:
# 
# ls -ld $ORACLE_HOME/dbs/orapw${ORACLE_SID}
# 
# Substitute ${ORACLE_SID} with the name of the ORACLE_SID for the database.
# 
# If permissions are granted for world access, this is a finding.
# 
# On Windows Systems (From Windows Explorer):
# 
# Browse to the %ORACLE_HOME\database\directory.
# 
# Select and right-click on the PWD%ORACLE_SID%.ora file, select Properties, select the Security tab.
# Substitute %ORACLE_SID% with the name of the ORACLE_SID for the database.
# 
# If permissions are granted to everyone, this is a finding.
# If any account other than the DBMS software installation account is listed, this is a finding.
# 
# 
# Disable use of the REMOTE_LOGIN_PASSWORDFILE where remote administration is not authorized by specifying a value of NONE.
# 
# If authorized, restrict use of a password file to exclusive use by each database by specifying a value of EXCLUSIVE.
# 
# 
# alter system set REMOTE_LOGIN_PASSWORDFILE = 'EXCLUSIVE' scope = spfile;
# 
# OR
# 
# alter system set REMOTE_LOGIN_PASSWORDFILE = 'NONE' scope = spfile;
# 
# The above SQL*Plus command will set the parameter to take effect at next system startup.
# 
# Restrict ownership and permissions on the Oracle password file to exclude world (Unix) or everyone (Windows).
# 
# More information regarding the ORAPWD file and the REMOTE_LOGIN_PASSWORDFILE parameter, can be found here:
# https://docs.oracle.com/database/121/ADMIN/dba.htm#ADMIN12478
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::orcl_pwd_file_ownership_and_permissions_should_be_lmted_and_rmt_login_pwdfile_parameter_must_be_s: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::orcl_pwd_file_ownership_and_permissions_should_be_lmted_and_rmt_login_pwdfile_parameter_must_be_s::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `orcl_pwd_file_ownership_and_permissions_should_be_lmted_and_rmt_login_pwdfile_parameter_must_be_s` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61431
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::orcl_pwd_file_ownership_and_permissions_should_be_lmted_and_rmt_login_pwdfile_parameter_must_be_s
{
  ora_secured_setup { "orcl_pwd_file_ownership_and_permissions_should_be_lmted_and_rmt_login_pwdfile_parameter_must_be_s on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
