#
# ora_secured::controls::owners_of_privileged_accounts_must_use_non_privileged_accounts_for_non_administrative_activities
#
# @summary Review procedures and practices.
# If there is not a policy requiring owners of privileged accounts to use non-privileged accounts for non-administrative activities, this is a finding.  If there is evidence that owners of privileged accounts do not adhere to this policy, this is a finding.
# 
# Require that DBAs and other privileged users use non-privileged accounts for non-administrative activities.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::owners_of_privileged_accounts_must_use_non_privileged_accounts_for_non_administrative_activities: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::owners_of_privileged_accounts_must_use_non_privileged_accounts_for_non_administrative_activities::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `owners_of_privileged_accounts_must_use_non_privileged_accounts_for_non_administrative_activities` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61597
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::owners_of_privileged_accounts_must_use_non_privileged_accounts_for_non_administrative_activities
{
  ora_secured_setup { "owners_of_privileged_accounts_must_use_non_privileged_accounts_for_non_administrative_activities on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
