#
# ora_secured::controls::procs_and_rstctns_for_import_of_prod_data_to_dev_dbs_must_be_doc_impl_and_followed
#
# @summary If the database being reviewed is not a production database or does not contain sensitive data, this check is not a finding.
# Review documented policy, procedures and proof of implementation for restrictions placed on data exports from the production database.
# 
# Policy and procedures should include that only authorized users have access to DBMS export utilities and that export data is properly sanitized prior to import to a development database.
# 
# Policy and procedures may also include that developers be granted the necessary clearance and need-to-know prior to import of production data.
# 
# If documented policy, procedures and proof of implementation are not present or complete, this is a finding.
# 
# If methods to sanitize sensitive data are required and not documented or followed, this is a finding.
# 
# Develop, document and implement policy and procedures that provide restrictions for production data export.
# 
# Require users and administrators assigned privileges that allow the export of production data from a production database to acknowledge understanding of export restrictions.
# 
# Restrict permissions allowing use or access to database export procedures or functions to authorized users.
# 
# Ensure sensitive data from production is sanitized prior to import to a development database (See check O121-BP-023300.)
# 
# Grant access and need-to-know to developers where allowed by policy.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::procs_and_rstctns_for_import_of_prod_data_to_dev_dbs_must_be_doc_impl_and_followed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::procs_and_rstctns_for_import_of_prod_data_to_dev_dbs_must_be_doc_impl_and_followed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `procs_and_rstctns_for_import_of_prod_data_to_dev_dbs_must_be_doc_impl_and_followed` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61501
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::procs_and_rstctns_for_import_of_prod_data_to_dev_dbs_must_be_doc_impl_and_followed
{
  ora_secured_setup { "procs_and_rstctns_for_import_of_prod_data_to_dev_dbs_must_be_doc_impl_and_followed on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
