#
# ora_secured::controls::prot_against_or_lmt_effects_of_org_def_types_of_denial_of_service_dos_attacks
#
# @summary Review DBMS settings to verify the DBMS implements measures to limit the effects of the organization-defined types of Denial of Service (DoS) attacks.
# If measures have not been implemented, this is a finding.
# 
# Check the $ORACLE_HOME/network/admin/listener.ora to see if a Rate Limit has been established.  A rate limit is used to prevent denial of service (DOS) attacks on a database or to control a logon storm such as may be caused by an application server reboot.
# 
# - - - - -
# Example of a listener configuration with rate limiting in effect:
# 
# CONNECTION_RATE_LISTENER=10
# 
# LISTENER=
#   (ADDRESS_LIST=
#     (ADDRESS=(PROTOCOL=tcp)(HOST=)(PORT=1521)(RATE_LIMIT=yes))
#     (ADDRESS=(PROTOCOL=tcp)(HOST=)(PORT=1522)(RATE_LIMIT=yes))
#     (ADDRESS=(PROTOCOL=tcp)(HOST=)(PORT=1526))
#   )
# LISTENER=
#   (ADDRESS_LIST=
#     (ADDRESS=(PROTOCOL=tcp)(HOST=)(PORT=1521)(RATE_LIMIT=8))
#     (ADDRESS=(PROTOCOL=tcp)(HOST=)(PORT=1522)(RATE_LIMIT=12))
#     (ADDRESS=(PROTOCOL=tcp)(HOST=)(PORT=1526))
#   )
# 
# Implement measures to limit the effects of organization-defined types of Denial of Service attacks.
# 
# Modify the $ORACLE_HOME/network/admin/listener.ora to establish a Rate Limit.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::prot_against_or_lmt_effects_of_org_def_types_of_denial_of_service_dos_attacks: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::prot_against_or_lmt_effects_of_org_def_types_of_denial_of_service_dos_attacks::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `prot_against_or_lmt_effects_of_org_def_types_of_denial_of_service_dos_attacks` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61783
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::prot_against_or_lmt_effects_of_org_def_types_of_denial_of_service_dos_attacks
{
  ora_secured_setup { "prot_against_or_lmt_effects_of_org_def_types_of_denial_of_service_dos_attacks on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
