#
# ora_secured::controls::prot_audit_recs_gen_as_a_result_of_rmt_acc_to_privd_accnts_and_execution_of_privd_funcs
#
# @summary If Standard Auditing is used:
# For table-based auditing (DB or DB,EXTENDED), review the DBMS permissions on the views and base tables holding the audit data.
# 
# For file-based auditing (OS, XML, or XML,EXTENDED), review the operating system/file system permissions on the audit file(s).
# 
# If permissions exist that enable unauthorized users to view audit data, this is a finding.
# 
# If permissions exist that enable any user (other than an account created specifically to manage log space and off-load audit records to a log management system) to modify or delete audit records, or create spurious audit records, this is a finding.
# 
# If Unified Auditing is used:
# AUDIT_ADMIN role. This role enables the creation of unified and fine-grained audit policies, use the AUDIT and NOAUDIT SQL statements, view audit data, and manage the audit trail administration. Grant this role only to trusted users.                                                                                                                                                                                                      
# 
# AUDIT_VIEWER role. This role enables users to view and analyze audit data. The kind of user who needs this role is typically an external auditor.
# 
# Check to ensure the authorized users have the correct roles. If permissions exist that enable unauthorized users to view audit data, this is a finding.
# 
# If permissions exist that enable any user (other than an account created specifically to manage log space and off-load audit records to a log management system) to modify or delete audit records, or create spurious audit records, this is a finding.
# 
# Add controls and modify permissions to protect database audit log records from modification, deletion, spurious creation, or unauthorized viewing.
# 
# If Unified Auditing is used:
# Grant the correct Audit roles to authorized users.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::prot_audit_recs_gen_as_a_result_of_rmt_acc_to_privd_accnts_and_execution_of_privd_funcs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::prot_audit_recs_gen_as_a_result_of_rmt_acc_to_privd_accnts_and_execution_of_privd_funcs::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `prot_audit_recs_gen_as_a_result_of_rmt_acc_to_privd_accnts_and_execution_of_privd_funcs` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61669
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::prot_audit_recs_gen_as_a_result_of_rmt_acc_to_privd_accnts_and_execution_of_privd_funcs
{
  ora_secured_setup { "prot_audit_recs_gen_as_a_result_of_rmt_acc_to_privd_accnts_and_execution_of_privd_funcs on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
