#
# ora_secured::controls::provide_a_mechanism_to_automatically_remove_or_disable_temporary_user_accounts_after_72_hours
#
# @summary If the organization has a policy, consistently enforced, forbidding the creation of emergency or temporary accounts, this is not a finding.
# If all user accounts are authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, this is not a finding.
# 
# Check DBMS settings, OS settings, and/or enterprise-level authentication/access mechanisms settings to determine if the site utilizes a mechanism whereby temporary are terminated after a 72 hour time period. If not, this is a finding.
# 
# If using database mechanisms to satisfy this requirement, use a profile with a distinctive name (for example, TEMPORARY_USERS), so that temporary users can be easily identified. Whenever a temporary user account is created, assign it to this profile.
# 
# Create a job to lock accounts under this profile that are more than 72 hours old.
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::provide_a_mechanism_to_automatically_remove_or_disable_temporary_user_accounts_after_72_hours: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::provide_a_mechanism_to_automatically_remove_or_disable_temporary_user_accounts_after_72_hours::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `provide_a_mechanism_to_automatically_remove_or_disable_temporary_user_accounts_after_72_hours` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61561
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::provide_a_mechanism_to_automatically_remove_or_disable_temporary_user_accounts_after_72_hours
{
  ora_secured_setup { "provide_a_mechanism_to_automatically_remove_or_disable_temporary_user_accounts_after_72_hours on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
