#
# ora_secured::controls::provide_a_real_time_alert_when_organization_defined_audit_failure_events_occur
#
# @summary Review Oracle Corp.
# , OS, or third-party logging software settings to determine whether a real-time alert will be sent to the appropriate personnel when auditing fails for any reason.
# 
# If real-time alerts are not sent upon auditing failure, this is a finding.
# 
# Configure logging software to send a real-time alert to appropriate personnel when auditing fails for any reason.
# 
# (Oracle recommends the use of Oracle Enterprise Manager.)
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::provide_a_real_time_alert_when_organization_defined_audit_failure_events_occur: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::provide_a_real_time_alert_when_organization_defined_audit_failure_events_occur::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `provide_a_real_time_alert_when_organization_defined_audit_failure_events_occur` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61645
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::provide_a_real_time_alert_when_organization_defined_audit_failure_events_occur
{
  ora_secured_setup { "provide_a_real_time_alert_when_organization_defined_audit_failure_events_occur on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
