#
# ora_secured::controls::remote_administration_must_be_disabled_for_the_oracle_connection_manager
#
# @summary View the cman.
# ora file in the ORACLE_HOME/network/admin directory.
# 
# If the file does not exist, the database is not accessed via Oracle Connection Manager and this check is not a finding.
# 
# If the entry and value for REMOTE_ADMIN is not listed or is not set to a value of NO (REMOTE_ADMIN = NO), this is a finding.
# 
# ora file in the ORACLE_HOME/network/admin directory of the Connection Manager.
# 
# Include the following line in the file:
# 
#   REMOTE_ADMIN = NO
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::remote_administration_must_be_disabled_for_the_oracle_connection_manager: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::remote_administration_must_be_disabled_for_the_oracle_connection_manager::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_administration_must_be_disabled_for_the_oracle_connection_manager` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61533
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::remote_administration_must_be_disabled_for_the_oracle_connection_manager
{
  ora_secured_setup { "remote_administration_must_be_disabled_for_the_oracle_connection_manager on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
