#
# ora_secured::controls::remote_login_passwordfile_is_set_to_none
#
# @summary The `remote_login_passwordfile` setting specifies whether or not Oracle checks
# for a password file during login and how many databases can use the password
# file. The setting should have a value of `NONE` or in the event you are running
# DR/Data Guard, `EXCLUSIVE` is an allowable value.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::remote_login_passwordfile_is_set_to_none: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::remote_login_passwordfile_is_set_to_none::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_login_passwordfile_is_set_to_none` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.7
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.7
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.6
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::remote_login_passwordfile_is_set_to_none()
{
  $sid = $title
  $unique = ora_secured::random_id(6)

  ora_secured_setup { "remote_login_passwordfile_is_set_to_none on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::parameter { "REMOTE_LOGIN_PASSWORDFILE@${sid}@${unique}":
    value => 'NONE',
  }
}
