#
# ora_secured::controls::remote_os_authent_is_set_to_false
#
# @summary The `remote_os_authent` setting determines whether or not OS 'roles' with the
# attendant privileges are allowed for remote client connections. This setting
# should have a value of `FALSE`.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::remote_os_authent_is_set_to_false: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::remote_os_authent_is_set_to_false::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_os_authent_is_set_to_false` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.8
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.8
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.7
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::remote_os_authent_is_set_to_false()
{
  $sid = $title
  $unique = ora_secured::random_id(6)

  ora_secured_setup { "remote_os_authent_is_set_to_false on ${sid}":
    ensure => 'present'
  }
  -> ora_secured::internal::parameter { "REMOTE_OS_AUTHENT@${sid}@${unique}":
    value => 'FALSE',
  }
}
