#
# ora_secured::controls::restrict_grants_to_sensitive_information_to_authorized_user_roles
#
# @summary Obtain a list of privileges assigned to user accounts.
# If access to sensitive information is granted to roles not authorized to access sensitive information, this is a finding.
# 
# If access to sensitive information is granted to individual accounts rather than to a role, this is a finding.
# 
# Define application user roles based on privilege and job function requirements.
# 
# Assign the required privileges to the role and assign the role to authorized application user accounts.
# 
# Revoke any privileges to sensitive information directly assigned to application user accounts.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::restrict_grants_to_sensitive_information_to_authorized_user_roles: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::restrict_grants_to_sensitive_information_to_authorized_user_roles::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `restrict_grants_to_sensitive_information_to_authorized_user_roles` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61581
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::restrict_grants_to_sensitive_information_to_authorized_user_roles
{
  ora_secured_setup { "restrict_grants_to_sensitive_information_to_authorized_user_roles on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
