#
# ora_secured::controls::rstrct_acc_to_sys_tables_and_other_config_info_or_metadata_to_dbas_or_other_auth_users
#
# @summary Review user privileges to system tables and configuration data stored in the Oracle database.
# If non-DBA users are assigned privileges to access system tables and tables containing configuration data, this is a finding.
# 
# To obtain a list of users and roles that have been granted access to any dictionary table, run the query:
# SELECT unique grantee from dba_tab_privs where table_name in
# (select table_name from dictionary)
# order by grantee;
# 
# To obtain a list of dictionary tables and assigned privileges granted to a specific user or role, run the query:
# SELECT grantee, table_name, privilege from dba_tab_privs where table_name in
# (select table_name from dictionary)
# and grantee = '<applicable account>';
# 
# Restrict accessibility of Oracle system tables and other configuration information or metadata to DBAs or other authorized users.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::rstrct_acc_to_sys_tables_and_other_config_info_or_metadata_to_dbas_or_other_auth_users: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::rstrct_acc_to_sys_tables_and_other_config_info_or_metadata_to_dbas_or_other_auth_users::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `rstrct_acc_to_sys_tables_and_other_config_info_or_metadata_to_dbas_or_other_auth_users` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61589
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::rstrct_acc_to_sys_tables_and_other_config_info_or_metadata_to_dbas_or_other_auth_users
{
  ora_secured_setup { "rstrct_acc_to_sys_tables_and_other_config_info_or_metadata_to_dbas_or_other_auth_users on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
