#
# ora_secured::controls::sensitive_info_frm_prod_db_exports_must_be_modified_before_import_to_a_dev_db
#
# @summary If the database being reviewed is a production database, this check is not a finding.
# Review policy, procedures and restrictions for data imports of production data containing sensitive information into development databases.
# 
# If data imports of production data are allowed, review procedures for protecting any sensitive data included in production exports.
# 
# If sensitive data is included in the exports and no procedures are in place to remove or modify the data to render it not sensitive prior to import into a development database or policy and procedures are not in place to ensure authorization of development personnel to access sensitive information contained in production data, this is a finding.
# 
# Develop, document and implement policy, procedures and restrictions for production data import.
# 
# Require any users assigned privileges that allow the export of production data from the database to acknowledge understanding of import policies, procedures and restrictions.
# 
# Restrict permissions of development personnel requiring use or access to production data imported into development databases containing sensitive information to authorized users.
# 
# Implement policy and procedures to modify or remove sensitive information in production exports prior to import into development databases.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::sensitive_info_frm_prod_db_exports_must_be_modified_before_import_to_a_dev_db: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::sensitive_info_frm_prod_db_exports_must_be_modified_before_import_to_a_dev_db::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sensitive_info_frm_prod_db_exports_must_be_modified_before_import_to_a_dev_db` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61453
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::sensitive_info_frm_prod_db_exports_must_be_modified_before_import_to_a_dev_db
{
  ora_secured_setup { "sensitive_info_frm_prod_db_exports_must_be_modified_before_import_to_a_dev_db on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
