#
# ora_secured::controls::supp_enforcement_of_log_acc_rstctns_ass_with_changes_to_dbms_config_and_to_db_itself
#
# @summary Review DBMS settings and vendor documentation to ensure the database supports and does not interfere with enforcement of logical access restrictions associated with changes to the DBMS configuration and to the database itself.
# If the DBMS software in any way restricts the implementation of logical access controls implemented to protect its integrity or availability, this is a finding.
# 
# Configure the DBMS to allow implementation of logical access restrictions aimed at protecting the DBMS from unauthorized changes to its configuration and to the database itself.
# 
# - - - - -
# When the Oracle Database is installed on a Unix-like operating system, the required umask is 022, and the file permissions are set so that any modifications to the startup files can only be performed by the owner of the software, a member of the group DBA, or the root user. Changing the umask has caused problems when patching the environment.  If changes are to be made, they should be reverted to the status they were in before the modification for patching and upgrades.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_enforcement_of_log_acc_rstctns_ass_with_changes_to_dbms_config_and_to_db_itself: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_enforcement_of_log_acc_rstctns_ass_with_changes_to_dbms_config_and_to_db_itself::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_enforcement_of_log_acc_rstctns_ass_with_changes_to_dbms_config_and_to_db_itself` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61671
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_enforcement_of_log_acc_rstctns_ass_with_changes_to_dbms_config_and_to_db_itself
{
  ora_secured_setup { "supp_enforcement_of_log_acc_rstctns_ass_with_changes_to_dbms_config_and_to_db_itself on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
