#
# ora_secured::controls::supp_org_reqs_to_encrpt_info_strd_in_db_and_info_extr_or_dervd_frm_db_and_strd_on_dig_med
#
# @summary If encryption is not required for the database and data derived from it, this is not a finding.
# Review DBMS settings to determine whether data stored on the database is encrypted according to organizational requirements.
# 
# If not, this is a finding.
# 
# Check the following settings to see if FIPS 140-2 encryption is configured.  If encryption is not configured, check with the DBA and SYSTEM Administrator to see if other mechanisms or third-party products are deployed to encrypt data stored in the database.
# 
# To see if Oracle is configured for FIPS 140-2 Transparent Data Encryption and/or DBMS_CRYPTO, enter the following SQL*Plus command:
# SHOW PARAMETER DBFIPS_140
# or the following SQL query:
# SELECT * FROM SYS.V$PARAMETER WHERE NAME = 'DBFIPS_140';
# If Oracle returns the value 'FALSE', or returns no rows, this is a finding.
# 
# To see if there are encrypted tablespaces enter the following SQL*Plus command:
# SELECT * FROM V$ENCRYPTED_TABLESPACES;
# If no rows are returned, then there are no encrypted tablespaces.
# 
# To see if there are encrypted columns within existing tables, enter the following SQL*Plus command:
# SELECT * FROM DBA_ENCRYPTED_COLUMNS;
# If no rows are returned, then there are no encrypted columns within existing tables.
# 
# Note: For the Solaris platform, when DBFIPS_140 is FALSE, TDE (but not DBMS_CRYPTO) can still operate
# in a FIPS 140-compliant manner if FIPS 140 operation is enabled for the Solaris Cryptographic Framework.
# 
# Configure cryptographic functions to use FIPS 140-2-compliant algorithms and hashing functions.
# 
# Configure the DBMS and/or the OS to encrypt data at rest according to the requirements of the organization.
# 
# The strength requirements are dependent upon data classification.
# 
# For unclassified data, where cryptography is required:
# AES 128 for encryption
# SHA 256 for hashing
# 
# NSA has established the suite B encryption requirements for protecting National Security Systems (NSS) as follows.
# AES 128 for Secret
# AES 256 for Top Secret
# SHA 256 for Secret
# SHA 384 for Top Secret
# 
# National Security System is defined as:
# (OMB Circular A-130) Any telecommunications or information system operated by the United States Government, the function, operation, or use of which (1) involves intelligence activities; (2) involves cryptologic activities related to national security; (3) involves command and control of military forces; (4) involves equipment that is an integral part of a weapon or weapons system; or (5) is critical to the direct fulfillment of military or intelligence missions, but excluding any system that is to be used for routine administrative and business applications (including payroll, finance, logistics, and personnel management applications).
# 
# There is more information on this topic in the Oracle Database 12c Advanced Security Administrator's Guide, which may be found at  https://docs.oracle.com/database/121/DBSEG/E48135-11.pdf.  (Note, however, that because of changes in Oracle's licensing policy, it is no longer necessary to purchase Oracle Advanced Security to use network encryption and advanced authentication.)
# 
# FIPS 140-2 documentation can be downloaded from http://csrc.nist.gov/publications/PubsFIPS.html#140-2
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_org_reqs_to_encrpt_info_strd_in_db_and_info_extr_or_dervd_frm_db_and_strd_on_dig_med: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_org_reqs_to_encrpt_info_strd_in_db_and_info_extr_or_dervd_frm_db_and_strd_on_dig_med::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_org_reqs_to_encrpt_info_strd_in_db_and_info_extr_or_dervd_frm_db_and_strd_on_dig_med` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61755
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_org_reqs_to_encrpt_info_strd_in_db_and_info_extr_or_dervd_frm_db_and_strd_on_dig_med
{
  ora_secured_setup { "supp_org_reqs_to_encrpt_info_strd_in_db_and_info_extr_or_dervd_frm_db_and_strd_on_dig_med on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
