#
# ora_secured::controls::supp_org_reqs_to_enforce_pwd_complexity_by_number_of_numeric_characters_used
#
# @summary If all user accounts are managed and authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, this is not a finding.
# For each profile that can be applied to accounts where authentication is under Oracle's control, determine the password verification function, if any, that is in use:
# 
# SELECT * FROM SYS.DBA_PROFILES
# WHERE RESOURCE_NAME = 'PASSWORD_VERIFY_FUNCTION'
# [AND PROFILE NOT IN (<list of non-applicable profiles>)]
# ORDER BY PROFILE;
# Bearing in mind that a profile can inherit from another profile, and the root profile is called DEFAULT, determine the name of the password verification function effective for each profile.
# 
# If, for any profile, the function name is null, this is a finding.
# 
# For each password verification function, examine its source code.
# 
# If it does not enforce the organization-defined minimum number of numeric characters (1 unless otherwise specified), this is a finding.
# 
# If all user accounts are authenticated by the OS or an enterprise-level authentication/access mechanism, and not by Oracle, no fix to the DBMS is required.
# 
# If any user accounts are managed by Oracle: Develop, test, and implement a password verification function that enforces DoD requirements.
# 
# Oracle supplies a sample function called ORA12C_STRONG_VERIFY_FUNCTION. This can be used as the starting point for a customized function. The script file is found in the following location on the server depending on OS:
# Windows:
# %ORACLE_HOME%\RDBMS\ADMIN\catpvf.sql
# UNIX/Linux:
# $ORACLE_HOME/rdbms/admin/catpvf.sql 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_org_reqs_to_enforce_pwd_complexity_by_number_of_numeric_characters_used: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_org_reqs_to_enforce_pwd_complexity_by_number_of_numeric_characters_used::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_org_reqs_to_enforce_pwd_complexity_by_number_of_numeric_characters_used` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61727
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_org_reqs_to_enforce_pwd_complexity_by_number_of_numeric_characters_used
{
  ora_secured_setup { "supp_org_reqs_to_enforce_pwd_complexity_by_number_of_numeric_characters_used on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
