#
# ora_secured::controls::supp_req_to_back_up_audit_data_and_recs_onto_a_diff_sys_or_med_than_sys_being_audited_on_an_org_d
#
# @summary Check with the database administrator, storage administrator or system administrator, as applicable at the site, to verify that Oracle is configured EITHER to perform backups of the audit data specifically, OR, with appropriate permissions granted, to permit a third-party tool to do so.
# Test the backup process.  Test the restore process (using a non-production system as the target).
# 
# If Oracle is not so configured, this is a finding.
# 
# If the test run of the backup and restore fails, this is a finding.
# 
# Utilize DBMS features or other software that supports the ability to back up audit data and records onto a system or media different from the system being audited on an organization-defined frequency.
# 
# EITHER use Oracle features (such as Backup or Data Pump) to perform backups of the audit data specifically, OR grant appropriate permissions to permit a third-party tool to do so.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::supp_req_to_back_up_audit_data_and_recs_onto_a_diff_sys_or_med_than_sys_being_audited_on_an_org_d: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::supp_req_to_back_up_audit_data_and_recs_onto_a_diff_sys_or_med_than_sys_being_audited_on_an_org_d::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `supp_req_to_back_up_audit_data_and_recs_onto_a_diff_sys_or_med_than_sys_being_audited_on_an_org_d` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61665
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::supp_req_to_back_up_audit_data_and_recs_onto_a_diff_sys_or_med_than_sys_being_audited_on_an_org_d
{
  ora_secured_setup { "supp_req_to_back_up_audit_data_and_recs_onto_a_diff_sys_or_med_than_sys_being_audited_on_an_org_d on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
