#
# ora_secured::controls::take_needed_steps_to_prot_data_at_rest_and_ensure_conf_and_int_of_app_data
#
# @summary If the application owner and Authorizing Official have determined that encryption of data at rest is NOT required, this is not a finding.
# Review DBMS settings to determine whether controls exist to protect the confidentiality and integrity of data at rest in the database.
# 
# If controls do not exist or are not enabled, this is a finding.
# 
# To ensure that the appropriate controls are in place, discuss the precautions taken with the site Database Administrators and System Administrators and try to modify data at rest.
# 
# Oracle recommends using Transparent Data Encryption to protect data.
# 
# In order to check to see if the data is encrypted, for example, upon an auditor's request, Oracle provides views that document the encryption status of the database. For TDE column encryption, use the view 'dba_encrypted_columns', which lists the owner, table name, column name, encryption algorithm, and salt for all encrypted columns. For TDE tablespace encryption, the following SQL statement lists all encrypted tablespaces with their encryption algorithm and corresponding, encrypted, data files. Issue the following commands to check to see if the data at rest is encrypted.
# 
# $ sqlplus connect as sysdba
# 
# SQL> SELECT t.name "TSName",
# e.encryptionalg "Algorithm",
# d.file_name "File Name"
# FROM v$tablespace t,
# v$encrypted_tablespaces e,
# dba_data_files d
# WHERE t.ts# = e.ts#
# and t.name = d.tablespace_name;
# 
# The next SQL statement lists the table owner, tables within encrypted tablespaces, and the encryption algorithm:
# 
# SQL> SELECT a.owner "Owner",
# a.table_name "Table Name",
# e.encryptionalg "Algorithm"
# FROM dba_tables a,
# v$encrypted_tablespaces e
# WHERE a.tablespace_name in (select t.name from v$tablespace t, v$encrypted_tablespaces e where t.ts# = e.ts#);
# 
# Apply appropriate controls to protect the confidentiality and integrity of data at rest in the database.
# 
# If no site-specific precautions are in place, use Oracle Advanced Security Option to encrypt data at rest.
# 
# If ASO is not an option, use site-specific procedures to secure data at rest.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::take_needed_steps_to_prot_data_at_rest_and_ensure_conf_and_int_of_app_data: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::take_needed_steps_to_prot_data_at_rest_and_ensure_conf_and_int_of_app_data::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `take_needed_steps_to_prot_data_at_rest_and_ensure_conf_and_int_of_app_data` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61771
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::take_needed_steps_to_prot_data_at_rest_and_ensure_conf_and_int_of_app_data
{
  ora_secured_setup { "take_needed_steps_to_prot_data_at_rest_and_ensure_conf_and_int_of_app_data on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
