#
# ora_secured::controls::term_netw_conns_ass_with_a_comms_session_at_end_of_session_or_15_minutes_of_inactivity
#
# @summary Review DBMS settings, OS settings, and vendor documentation to verify network connections are terminated when a database communications session is ended or after 15 minutes of inactivity.
# If the network connection is not terminated, this is a finding.
# 
# The defined duration for these timeouts 15 minutes, except to fulfill documented and validated mission requirements.
# 
# Configure DBMS and/or OS settings to disconnect network sessions when database communication sessions have ended or after the DoD-defined period of inactivity.
# 
# To configure this in Oracle, modify each relevant profile.  The resource name is IDLE_TIME, which is expressed in minutes.  Using PPPPPP as an example of a profile, set the timeout to 15 minutes with:
# ALTER PROFILE PPPPPP LIMIT IDLE_TIME 15;
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::term_netw_conns_ass_with_a_comms_session_at_end_of_session_or_15_minutes_of_inactivity: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::term_netw_conns_ass_with_a_comms_session_at_end_of_session_or_15_minutes_of_inactivity::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `term_netw_conns_ass_with_a_comms_session_at_end_of_session_or_15_minutes_of_inactivity` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61757
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::term_netw_conns_ass_with_a_comms_session_at_end_of_session_or_15_minutes_of_inactivity
{
  ora_secured_setup { "term_netw_conns_ass_with_a_comms_session_at_end_of_session_or_15_minutes_of_inactivity on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
