#
# ora_secured::controls::unauthorized_database_links_must_not_be_defined_and_active
#
# @summary From SQL*Plus:
# select db_link||': '||host from dba_db_links;
# 
# If no links are returned, this check is not a finding.
# 
# Review documentation for definitions of authorized database links to external interfaces.
# 
# The documentation should include:
# 
# - Any remote access to the database
# - The purpose or function of the remote connection
# - Any access to data or procedures stored externally to the local DBMS
# - Any network ports or protocols used by remote connections, whether the remote connection is to a production, test, or development system
# - Any security accounts used by DBMS to access remote resources or objects
# 
# If any unauthorized database links are defined or the definitions do not match the documentation, this is a finding.
# 
# Note: findings for production-development links under this check are assigned to the production database only.
# 
# If any database links are defined between the production database and any test or development databases, this is a finding.
# 
# If remote interface documentation does not exist or is incomplete, this is a finding.
# 
# Document all remote or external interfaces used by the DBMS to connect to or allow connections from remote or external sources.
# 
# Include with the documentation as appropriate, any network ports or protocols, security accounts, and the sensitivity of any data exchanged.
# 
# Do not define or configure database links between production databases and test or development databases.
# 
# Note: Oracle Database Advanced Replication is deprecated in Oracle Database 12c. Use Oracle GoldenGate to replace all features of Advanced Replication, including multimaster replication, updatable materialized views, hierarchical materialized views, and deployment templates.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::unauthorized_database_links_must_not_be_defined_and_active: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::unauthorized_database_links_must_not_be_defined_and_active::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `unauthorized_database_links_must_not_be_defined_and_active` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61451
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::unauthorized_database_links_must_not_be_defined_and_active
{
  ora_secured_setup { "unauthorized_database_links_must_not_be_defined_and_active on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
