#
# ora_secured::controls::unused_database_components_dbms_software_and_database_objects_must_be_removed
#
# @summary Run this query to produce a list of components and features installed with the database:
# SELECT comp_id, comp_name, version, status from dba_registry
# where comp_id not in ('CATALOG','CATPROC','XDB');
# 
# Review the list.  If unused components are installed and are not documented and authorized, this is a finding.
# 
# Starting with releases 11.1.0.7.x and above, all products are installed by default and the option to customize the product/component selection is no longer possible with the exception of those listed here:
# 
# Oracle JVM,
# Oracle Text,
# Oracle Multimedia,
# Oracle OLAP,
# Oracle Spatial,
# Oracle Label Security, 
# Oracle Application Express,
# Oracle Database Vault
# 
# If any components are required for operation of applications that will be accessing the DBMS, include them in the system documentation.
# 
# One cannot remove components, either via Database Configuration Assistant (DBCA) or manually once the database has been created, either from a container or a non-container database.
# 
# One can, however, use DBCA to create a non-container database and remove components during the creation process, before the database is created.
# 
# When using DBCA to create a custom non-container database, select
# creation mode = advanced
# Database Template = Custom
# Database Options..Database Component.
# 
# Components that can be selected or de-selected are:
# Oracle JVM, Oracle Text, Oracle Multimedia, Oracle OLAP, Oracle Spatial, Oracle Label Security, Oracle Application Express, Oracle Database Vault
# 
# For a container database (CDB), the CDB$ROOT must have all possible database components available.  This is because, when a pluggable database (PDB) is plugged into the CDB, the CDB must have the same components installed as the PDB.  Since we do not know what components the PDBS may have, the CDB must be able to support all possible PDB configurations.
# 
# Components installed in the CDB$ROOT do not need to be licensed.  Components are only considered to be used if they are installed in the PDB.
# 
# To configure a PDB to only use specific components, do the following:
# 
# 1) Create a non-CDB 12.1 database and configure that database with the components desired.
# 
# 2) Plug the non-CDB database into a CDB database, creating a new PDB.  If wanted, can then create additional clones from the new PDB.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::unused_database_components_dbms_software_and_database_objects_must_be_removed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::unused_database_components_dbms_software_and_database_objects_must_be_removed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `unused_database_components_dbms_software_and_database_objects_must_be_removed` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61679
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::unused_database_components_dbms_software_and_database_objects_must_be_removed
{
  ora_secured_setup { "unused_database_components_dbms_software_and_database_objects_must_be_removed on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
