#
# ora_secured::controls::unused_db_components_that_are_integrated_in_dbms_and_cannot_be_uninstalled_must_be_disabled
#
# @summary Run this query to check to see what integrated components are installed in the database:
# SELECT parameter, value
# from v$option
# where parameter in 
# (
# 'Data Mining',
# 'Oracle Database Extensions for .NET',
# 'OLAP',
# 'Partitioning',
# 'Real Application Testing'
# );
# 
# This will return all of the relevant database options and their status. TRUE means that the option is installed. If the option is not installed, the option will be set to FALSE.
# 
# Review the options and check the system documentation to see what is required.  If all listed components are authorized to be in use, this is not a finding.
# 
# If any unused components or features are listed by the query as TRUE, this is a finding.
# 
# In the system documentation list the integrated components required for operation of applications that will be accessing the DBMS.
# 
# For Oracle Database 12.1, only the following components can be enabled/disabled:
# 
# Oracle Data Mining (dm)
# Oracle Database Extensions for .NET (ode_net)
# Oracle OLAP (olap)
# Oracle Partitioning (partitioning)
# Real Application Testing (rat)
# 
# Use the chopt utility (an Oracle-supplied operating system command that resides in the <Oracle Home path>/bin directory) to disable each option that should not be available.  The command format is 
# 
#             chopt <enable|disable> <option>
# where <option> is any of the abbreviations in parentheses in the list above.  For example, to disable Real Application Testing, issue the following command at an OS prompt:
# 
#             chopt disable rat
# 
# Restart the Oracle service.
# 
# (See My Oracle Support Document 948061.1 for more on the chopt command.)
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::unused_db_components_that_are_integrated_in_dbms_and_cannot_be_uninstalled_must_be_disabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::unused_db_components_that_are_integrated_in_dbms_and_cannot_be_uninstalled_must_be_disabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `unused_db_components_that_are_integrated_in_dbms_and_cannot_be_uninstalled_must_be_disabled` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61681
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::unused_db_components_that_are_integrated_in_dbms_and_cannot_be_uninstalled_must_be_disabled
{
  ora_secured_setup { "unused_db_components_that_are_integrated_in_dbms_and_cannot_be_uninstalled_must_be_disabled on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
