#
# ora_secured::controls::use_of_the_dbms_installation_account_must_be_logged
#
# @summary Review documented and implemented procedures for monitoring the use of the DBMS software installation account in the System Security Plan.
# If use of this account is not monitored or procedures for monitoring its use do not exist or are incomplete, this is a finding.
# 
# Note: On Windows systems, The Oracle DBMS software is installed using an account with administrator privileges. Ownership should be reassigned to a dedicated OS account used to operate the DBMS software. If monitoring does not include all accounts with administrator privileges on the DBMS host, this is a finding.
# 
# Develop, document and implement a logging procedure for use of the DBMS software installation account that provides accountability to individuals for any actions taken by the account.
# 
# Host system audit logs should be included in the DBMS account usage log along with an indication of the person who accessed the account and an explanation for the access.
# 
# Ensure all accounts with administrator privileges are monitored for DBMS host on Windows OS platforms.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::use_of_the_dbms_installation_account_must_be_logged: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::use_of_the_dbms_installation_account_must_be_logged::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `use_of_the_dbms_installation_account_must_be_logged` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61489
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::use_of_the_dbms_installation_account_must_be_logged
{
  ora_secured_setup { "use_of_the_dbms_installation_account_must_be_logged on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
