#
# ora_secured::controls::use_org_def_replay_resistant_auth_mechs_for_netw_acc_to_privd_accnts
#
# @summary Review DBMS settings, OS settings, and/or enterprise-level authentication/access mechanism settings to determine whether organization-defined replay-resistant authentication mechanisms for network access to privileged accounts exist.
# If these mechanisms do not exist, this is a finding.
# 
# To check that network encryption is enabled and using site-specified encryption procedures, look in SQLNET.ORA, located at $ORACLE_HOME/network/admin/sqlnet.ora. (Note: This assumes that a single sqlnet.ora file, in the default location, is in use. Please see the supplemental file "Non-default sqlnet.ora configurations.pdf" for how to find multiple and/or differently located sqlnet.ora files.) If encryption is set, entries like the following will be present:
# 
# SQLNET.CRYPTO_CHECKSUM_TYPES_SERVER= (SHA384)SQLNET.ENCRYPTION_TYPES_SERVER= (AES256)SQLNET.CRYPTO_CHECKSUM_SERVER = required
# 
# SQLNET.CRYPTO_CHECKSUM_TYPES_CLIENT= (SHA384)
# SQLNET.ENCRYPTION_TYPES_CLIENT= (AES256)
# SQLNET.CRYPTO_CHECKSUM_CLIENT = requested
# 
# (The values assigned to the parameters may be different, the combination of parameters may be different, and not all of the example parameters will necessarily exist in the file.)
# 
# Configure DBMS, OS and/or enterprise-level authentication/access mechanism to utilize replay-resistant authentication mechanisms such as nonces (e.g., numbers generated for a specific one-time use) or challenges (e.g., TLS, WS_Security), and time synchronous or challenge-response one-time authenticators.
# 
# If appropriate, apply Oracle Data Network Encryption to protect against replay mechanisms.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::use_org_def_replay_resistant_auth_mechs_for_netw_acc_to_privd_accnts: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::use_org_def_replay_resistant_auth_mechs_for_netw_acc_to_privd_accnts::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `use_org_def_replay_resistant_auth_mechs_for_netw_acc_to_privd_accnts` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61713
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::use_org_def_replay_resistant_auth_mechs_for_netw_acc_to_privd_accnts
{
  ora_secured_setup { "use_org_def_replay_resistant_auth_mechs_for_netw_acc_to_privd_accnts on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
